@@ -9,8 +9,8 @@ called for the first time).
 """
 #============================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/business/gmClinicalRecord.py,v $
-# $Id: gmClinicalRecord.py,v 1.243 2007/04/25 21:59:15 ncq Exp $
-__version__ = "$Revision: 1.243 $"
+# $Id: gmClinicalRecord.py,v 1.252 2007/10/25 12:26:05 ncq Exp $
+__version__ = "$Revision: 1.252 $"
 __author__ = "K.Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL"
 
@@ -44,6 +44,7 @@ _log = gmLog.gmDefLog
 _log.Log(gmLog.lData, __version__)
 
 _me = None
+_here = None
 
 _func_ask_user = None
 #============================================================
@@ -57,10 +58,13 @@ class cClinicalRecord(object):
 		- no connection to database possible
 		- patient referenced by aPKey does not exist
 		"""
+		from Gnumed.business import gmSurgery, gmPerson
 		global _me
 		if _me is None:
-			from Gnumed.business import gmPerson
 			_me = gmPerson.gmCurrentProvider()
+		global _here
+		if _here is None:
+			_here = gmSurgery.gmCurrentPractice()
 
 		# ...........................................
 		# this is a hack to speed up get_encounters()
@@ -115,9 +119,6 @@ select fk_encounter from
 #		sig = "%s:%s" % (gmSignals.vacc_mod_db(), self.pk_patient)
 #		self._conn_pool.Unlisten(service = 'historica', signal = sig, callback = self.db_callback_vaccs_modified)
 
-#		sig = "%s:%s" % (gmSignals.allg_mod_db(), self.pk_patient)
-#		self._conn_pool.Unlisten(service = 'historica', signal = sig, callback = self._db_callback_allg_modified)
-
 		return True
 	#--------------------------------------------------------
 	# messaging
@@ -128,10 +129,6 @@ select fk_encounter from
 #		if not self._conn_pool.Listen('historica', sig, self.db_callback_vaccs_modified):
 #			return None
 
-#		sig = "%s:%s" % (gmSignals.allg_mod_db(), self.pk_patient)
-#		if not self._conn_pool.Listen(service = 'historica', signal = sig, callback = self._db_callback_allg_modified):
-#			return None
-
 #		sig = "%s:%s" % (gmSignals.health_issue_change_db(), self.pk_patient)
 #		if not self._conn_pool.Listen(service = 'historica', signal = sig, callback = self._health_issues_modified):
 #			return None
@@ -150,14 +147,6 @@ select fk_encounter from
 		gmDispatcher.send(signal = gmSignals.vaccinations_updated(), sender = self.__class__.__name__)
 		return True
 	#--------------------------------------------------------
-	def _db_callback_allg_modified(self):
-		try:
-			del self.__db_cache['allergies']
-		except KeyError:
-			pass
-		gmDispatcher.send(signal = gmSignals.allergy_updated(), sender = self.__class__.__name__)
-		return 1
-	#--------------------------------------------------------
 	def _health_issues_modified(self):
 		try:
 			del self.__db_cache['health issues']
@@ -171,10 +160,10 @@ select fk_encounter from
 		return 1
 	#--------------------------------------------------------
 	def _db_callback_episodes_modified(self):
-		try:
-			del self.__db_cache['episodes']
-		except KeyError:
-			pass
+#		try:
+#			del self.__db_cache['episodes']
+#		except KeyError:
+#			pass
 		try:
 			del self.__db_cache['problems']
 		except KeyError:
@@ -202,20 +191,7 @@ select fk_encounter from
 			return None
 		return data
 	#--------------------------------------------------------
-	def _build_narrative_cache_from_rows(self, rows, idx):
-		for row in rows:
-			narr_row = {
-				'pk_field': 'pk_narrative',
-				'idx': idx,
-				'data': row
-			}
-			narr = gmClinNarrative.cNarrative(row=narr_row)
-			self.__db_cache['narrative'].append(narr)
-
-		return True
-	#--------------------------------------------------------
-	def get_clin_narrative(self, since=None, until=None, encounters=None,
-		episodes=None, issues=None, soap_cats=None):
+	def get_clin_narrative(self, since=None, until=None, encounters=None, episodes=None, issues=None, soap_cats=None):
 		"""Get SOAP notes pertinent to this encounter.
 
 			since
@@ -231,27 +207,31 @@ select fk_encounter from
 			soap_cats
 				- list of SOAP categories of the narrative to be retrieved
 		"""
-		try:
-			self.__db_cache['narrative']
-		except KeyError:
-			cmd = u"select * from clin.v_pat_narrative where pk_patient=%s order by date"
-			rows, idx = gmPG2.run_ro_queries(queries=[{'cmd': cmd, 'args': [self.pk_patient]}], get_col_idx=True)
-			self.__db_cache['narrative'] = []
-			self._build_narrative_cache_from_rows(rows, idx)
+		cmd = u"""
+			select cvpn.*, (select rank from clin.soap_cat_ranks where soap_cat = cvpn.soap_cat) as soap_rank
+			from clin.v_pat_narrative cvpn
+			where pk_patient = %s
+			order by date, soap_rank
+		"""
+		rows, idx = gmPG2.run_ro_queries(queries=[{'cmd': cmd, 'args': [self.pk_patient]}], get_col_idx=True)
+
+		filtered_narrative = [ gmClinNarrative.cNarrative(row = {'pk_field': 'pk_narrative', 'idx': idx, 'data': row}) for row in rows ]
 
-		# ok, let's constrain our list
-		filtered_narrative = []
-		filtered_narrative.extend(self.__db_cache['narrative'])
 		if since is not None:
 			filtered_narrative = filter(lambda narr: narr['date'] >= since, filtered_narrative)
+
 		if until is not None:
 			filtered_narrative = filter(lambda narr: narr['date'] < until, filtered_narrative)
+
 		if issues is not None:
 			filtered_narrative = filter(lambda narr: narr['pk_health_issue'] in issues, filtered_narrative)
+
 		if episodes is not None:
 			filtered_narrative = filter(lambda narr: narr['pk_episode'] in episodes, filtered_narrative)
+
 		if encounters is not None:
 			filtered_narrative = filter(lambda narr: narr['pk_encounter'] in encounters, filtered_narrative)
+
 		if soap_cats is not None:
 			soap_cats = map(lambda c: c.lower(), soap_cats)
 			filtered_narrative = filter(lambda narr: narr['soap_cat'] in soap_cats, filtered_narrative)
@@ -651,15 +631,12 @@ where
 			episode_id = episode_id
 		)
 
-		gmDispatcher.send(signal = gmSignals.allergy_updated())
-
 		return new_allergy
 	#--------------------------------------------------------
 	def delete_allergy(self, pk_allergy=None):
 		cmd = u'delete from clin.allergy where pk=%(pk_allg)s'
 		args = {'pk_allg': pk_allergy}
 		gmPG2.run_rw_queries(queries = [{'cmd': cmd, 'args': args}])
-		gmDispatcher.send(signal = gmSignals.allergy_updated())
 	#--------------------------------------------------------
 	def ensure_has_allergic_state(self):
 		cmd = u'insert into clin.allergy_state (fk_patient, has_allergy) values (%(pat)s, %(state)s)'
@@ -676,7 +653,6 @@ where
 		cmd = u'update clin.allergy_state set has_allergy = %(state)s where fk_patient = %(pat)s'
 		args = {'pat': self.pk_patient, 'state': state}
 		gmPG2.run_rw_queries(queries = [{'cmd': cmd, 'args': args}])
-		gmDispatcher.send(signal = gmSignals.allergy_updated())
 		return True
 
 	def _get_allergic_state(self):
@@ -701,21 +677,23 @@ where
 		tmp = []
 		for r in rows:
 			tmp.append(gmEMRStructItems.cEpisode(row = {'data': r, 'idx': idx, 'pk_field': 'pk_episode'}))
-		self.__db_cache['episodes'] = tmp
 
 		# now filter
-		if id_list is None and issues is None and open_status is None:
-			return self.__db_cache['episodes']
+		if (id_list is None) and (issues is None) and (open_status is None):
+			return tmp
+
 		# ok, let's filter episode list
 		filtered_episodes = []
-		filtered_episodes.extend(self.__db_cache['episodes'])
+		filtered_episodes.extend(tmp)
 		if open_status is not None:
 			filtered_episodes = filter(lambda epi: epi['episode_open'] == open_status, filtered_episodes)
 
 		if issues is not None:
 			filtered_episodes = filter(lambda epi: epi['pk_health_issue'] in issues, filtered_episodes)
+
 		if id_list is not None:
 			filtered_episodes = filter(lambda epi: epi['pk_episode'] in id_list, filtered_episodes)
+
 		return filtered_episodes
 	#------------------------------------------------------------------
 	def get_episodes_by_encounter(self, pk_encounter=None):
@@ -1178,7 +1156,7 @@ where
 		cfg_db = gmCfg.cCfgSQL()
 		min_ttl = cfg_db.get2 (
 			option = u'encounter.minimum_ttl',
-			workplace = _me.workplace,
+			workplace = _here.active_workplace,
 			bias = u'user',
 			default = u'1 hour 30 minutes'
 		)
@@ -1210,13 +1188,13 @@ where
 		cfg_db = gmCfg.cCfgSQL()
 		min_ttl = cfg_db.get2 (
 			option = u'encounter.minimum_ttl',
-			workplace = _me.workplace,
+			workplace = _here.active_workplace,
 			bias = u'user',
 			default = u'1 hour 30 minutes'
 		)
 		max_ttl = cfg_db.get2 (
 			option = u'encounter.maximum_ttl',
-			workplace = _me.workplace,
+			workplace = _here.active_workplace,
 			bias = u'user',
 			default = u'6 hours'
 		)
@@ -1425,6 +1403,7 @@ where
 		cmd = u"""
 delete from clin.encounter where 
 	fk_patient = %(pat)s and
+	age(last_affirmed) > '1 week'::interval and
 	pk not in (select fk_encounter from clin.clin_root_item) and
 	pk not in (select fk_encounter from blobs.doc_med) and
 	pk not in (select fk_encounter from clin.operation)
@@ -1624,6 +1603,33 @@ if __name__ == "__main__":
 		_log.LogException('unhandled exception', sys.exc_info(), verbose=1)
 #============================================================
 # $Log: gmClinicalRecord.py,v $
+# Revision 1.252  2007/10/25 12:26:05  ncq
+# - cleanup
+#
+# Revision 1.251  2007/10/25 12:15:39  ncq
+# - we don't send allergy_updated() signal anymore, the backend does it for us
+#
+# Revision 1.250  2007/10/08 13:22:42  ncq
+# - avoid circular import
+#
+# Revision 1.249  2007/10/08 13:17:55  ncq
+# - missing gmPerson import
+#
+# Revision 1.248  2007/10/07 12:22:51  ncq
+# - workplace property now on gmSurgery.gmCurrentPractice() borg
+#
+# Revision 1.247  2007/09/24 22:07:32  ncq
+# - be careful about deleting empty encounters - make sure they are at least 1 week old
+#
+# Revision 1.246  2007/09/07 10:55:40  ncq
+# - order by in get_clin_narrative()
+#
+# Revision 1.245  2007/06/28 12:30:05  ncq
+# - uncache get_clin_narrative access
+#
+# Revision 1.244  2007/06/19 12:40:40  ncq
+# - cleanup
+#
 # Revision 1.243  2007/04/25 21:59:15  ncq
 # - improve message on very-recent-encounter
 #
