@@ -7,26 +7,30 @@ license: GPL
 """
 #============================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/business/gmDemographicRecord.py,v $
-# $Id: gmDemographicRecord.py,v 1.88 2007/03/23 15:01:36 ncq Exp $
-__version__ = "$Revision: 1.88 $"
+# $Id: gmDemographicRecord.py,v 1.93 2007/12/03 20:41:07 ncq Exp $
+__version__ = "$Revision: 1.93 $"
 __author__ = "K.Hilbert <Karsten.Hilbert@gmx.net>, I.Haywood <ihaywood@gnu.org>"
 
 # stdlib
 import sys, os.path, time, string
 
+
 # 3rd party
 import mx.DateTime as mxDT
 
-if __name__ == '__main__':
-	sys.path.insert(0, '../../')
 
 # GNUmed
-from Gnumed.pycommon import gmLog, gmExceptions, gmSignals, gmDispatcher, gmMatchProvider, gmI18N, gmBusinessDBObject, gmPG2
+if __name__ == '__main__':
+	sys.path.insert(0, '../../')
+from Gnumed.pycommon import gmLog, gmDispatcher, gmBusinessDBObject, gmPG2, gmTools
 from Gnumed.business import gmMedDoc
 
+
 _log = gmLog.gmDefLog
 _log.Log(gmLog.lInfo, __version__)
 
+
+__comm_list = None
 #===================================================================
 class cAddress(gmBusinessDBObject.cBusinessDBObject):
 	"""A class representing an entity in itself.
@@ -51,14 +55,13 @@ class cAddress(gmBusinessDBObject.cBusinessDBObject):
 	_cmds_store_payload = [
 		u"""update dem.address set
 				aux_street = %(notes_street)s,
-				number = %(number)s,
 				subunit = %(subunit)s,
 				addendum = %(notes_subunit)s,
 				lat_lon = %(lat_lon_street)s
 			where id=%(pk_address)s and xmin=%(xmin_address)s""",
 		u"select xmin as xmin_address from dem.address where id=%(pk_address)s"
 	]
-	_updatable_fields = ['notes_street', 'number', 'subunit', 'notes_subunit', 'lat_lon_address']
+	_updatable_fields = ['notes_street', 'subunit', 'notes_subunit', 'lat_lon_address']
 #===================================================================
 class cPatientAddress(gmBusinessDBObject.cBusinessDBObject):
 
@@ -68,7 +71,7 @@ class cPatientAddress(gmBusinessDBObject.cBusinessDBObject):
 			where id=%(pk_lnk_person_org_address)s and xmin=%(xmin_lnk_person_org_address)s""",
 		u"""select xmin from dem.lnk_person_org_address where id=%(pk_lnk_person_org_address)s"""
 	]
-	_updatable_fields = ['id_type']
+	_updatable_fields = ['pk_address_type']
 	#---------------------------------------------------------------
 	def get_identities(self, same_lastname=False):
 		pass
@@ -209,14 +212,13 @@ def getExtIDTypes (context = 'p'):
 		return {}
 	return dict (rl)
 #----------------------------------------------------------------
-def getCommChannelTypes():
-	"""Gets the dictionary of comm channel types to internal ID"""
-	row_list = gmPG.run_ro_query('personalia', "select description, id from dem.enum_comm_types")
-	if row_list is None:
-		return None
-	if len (row_list) == 0:
-		return None
-	return dict(row_list)
+def get_comm_channel_types():
+	global __comm_list
+	if __comm_list is None:
+		cmd = u"select pk, description from dem.enum_comm_types"
+		rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd}])
+		__comm_list = rows
+	return __comm_list
 #----------------------------------------------------------------
 def getRelationshipTypes():
 	"""Gets a dictionary of relationship types to internal id"""
@@ -351,19 +353,20 @@ def address_exists(country=None, state=None, urb=None, suburb=None, postcode=Non
 		return None
 	return rows[0][0]
 #------------------------------------------------------------
-def create_address(country=None, state=None, urb=None, suburb=None, postcode=None, street=None, number=None, subunit=None, notes_street=None, notes_subunit=None):
-	# FIXME: if country/state/urb are None pull them from address of practice
+def create_address(country=None, state=None, urb=None, suburb=None, postcode=None, street=None, number=None, subunit=None):
+
+	if suburb is not None:
+		suburb = gmTools.none_if(suburb.strip(), u'')
+
 	pk_address = address_exists (
-		country=country,
-		state=state,
-		urb=urb,
-		suburb=suburb,
-		postcode=postcode,
-		street=street,
-		number=number,
-		subunit=subunit,
-		notes_street=notes_street,
-		notes_subunit=notes_subunit
+		country = country,
+		state = state,
+		urb = urb,
+		suburb = suburb,
+		postcode = postcode,
+		street = street,
+		number = number,
+		subunit = subunit
 	)
 	if pk_address is not None:
 		return cAddress(aPK_obj=pk_address)
@@ -394,16 +397,11 @@ def create_address(country=None, state=None, urb=None, suburb=None, postcode=Non
 
 	if suburb is not None:
 		queries = [{
-			'cmd': u"update dem.street set suburb = %(suburb)s where id=%(pk_street)s",
+			# CAVE: suburb will be ignored if there already is one
+			'cmd': u"update dem.street set suburb = %(suburb)s where id=%(pk_street)s and suburb is Null",
 			'args': {'suburb': suburb, 'pk_street': adr['pk_street']}
 		}]
-
-	if notes_street is not None:
-		adr['notes_street'] = notes_street
-	if notes_subunit is not None:
-		adr['notes_subunit'] = notes_subunit
-
-	adr.save_payload()
+		rows, idx = gmPG2.run_rw_queries(queries = queries)
 
 	return adr
 #------------------------------------------------------------
@@ -444,8 +442,8 @@ if __name__ == "__main__":
 			suburb ='Sellerhausen',
 			postcode ='04318',
 			street = u'Cunnersdorfer Strasse',
-			number = '11',
-			notes_subunit = '4.Stock rechts'
+			number = '11'
+#			,notes_subunit = '4.Stock rechts'
 		)
 		print "created existing address"
 		print address
@@ -460,7 +458,7 @@ if __name__ == "__main__":
 			postcode ='04318',
 			street = u'Cunnersdorfer Strasse',
 			number = '11',
-			notes_subunit = '4.Stock rechts',
+#			notes_subunit = '4.Stock rechts',
 			subunit = su
 		)
 		print "created new address with subunit", su
@@ -480,7 +478,7 @@ if __name__ == "__main__":
 	sys.exit()
 
 	_log.SetAllLogLevels(gmLog.lData)
-	gmDispatcher.connect(_post_patient_selection, gmSignals.post_patient_selection())
+	gmDispatcher.connect(_post_patient_selection, 'post_patient_selection')
 	while 1:
 		pID = raw_input('a patient: ')
 		if pID == '':
@@ -502,6 +500,22 @@ if __name__ == "__main__":
 		print "--------------------------------------"
 #============================================================
 # $Log: gmDemographicRecord.py,v $
+# Revision 1.93  2007/12/03 20:41:07  ncq
+# - get_comm_channel_types()
+#
+# Revision 1.92  2007/12/02 20:56:37  ncq
+# - adjust to table changes
+#
+# Revision 1.91  2007/11/17 16:10:53  ncq
+# - improve create_address()
+# - cleanup and fixes
+#
+# Revision 1.90  2007/11/12 22:52:01  ncq
+# - create_address() now doesn't care about non-changing fields
+#
+# Revision 1.89  2007/11/07 22:59:31  ncq
+# - don't allow editing number on address
+#
 # Revision 1.88  2007/03/23 15:01:36  ncq
 # - no more person['id']
 #
