@@ -1,7 +1,7 @@
 #!/bin/sh
 
 # $Source: /sources/gnumed/gnumed/gnumed/client/gm-from-cvs.sh,v $
-# $Revision: 1.8 $
+# $Revision: 1.10 $
 
 # maybe force some locale setting here
 #export LANG=fr
@@ -18,5 +18,6 @@ LOG="gm-from-cvs.log"
 rm -vf $LOG
 
 # run
-python wxpython/gnumed.py --log-file=$LOG --conf-file=gm-from-cvs.conf --debug --override-schema-check
+python wxpython/gnumed.py --log-file=$LOG --conf-file=gm-from-cvs.conf --override-schema-check --debug
+# --slave
 # --profile=gm-from-cvs.prof
