@@ -12,12 +12,12 @@ def resultset_functional_batchgenerator(cursor, size=100):
 """
 # =======================================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/pycommon/gmPG2.py,v $
-__version__ = "$Revision: 1.46 $"
+__version__ = "$Revision: 1.63.2.1 $"
 __author__  = "K.Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = 'GPL (details at http://www.gnu.org)'
 
 # stdlib
-import time, locale, sys, re, os, codecs, types, datetime
+import time, locale, sys, re as regex, os, codecs, types, datetime
 
 
 # GNUmed
@@ -95,8 +95,10 @@ known_schema_hashes = {
 	'v2': 'b09d50d7ed3f91ddf4c4ddb8ea507720',
 	'v3': 'e73718eaf230d8f1d2d01afa8462e176',
 	'v4': '4428ccf2e54c289136819e701bb095ea',
-	'v5': '7e7b093af57aea48c288e76632a382e5',	# old (v1)
-	'v6': '90e2026ac2efd236da9c8608b8685b2d'	# new (v2)
+	'v5': '7e7b093af57aea48c288e76632a382e5',	# old (v1) style hash
+	'v6': '90e2026ac2efd236da9c8608b8685b2d',	# new (v2) style hash
+	'v7': '6c9f6d3981483f8e9433df99d1947b27',
+	'v8': '89b13a7af83337c3aad153b717e52360'
 }
 
 map_schema_hash2version = {
@@ -104,7 +106,9 @@ map_schema_hash2version = {
 	'e73718eaf230d8f1d2d01afa8462e176': 'v3',
 	'4428ccf2e54c289136819e701bb095ea': 'v4',
 	'7e7b093af57aea48c288e76632a382e5': 'v5',
-	'90e2026ac2efd236da9c8608b8685b2d': 'v6'
+	'90e2026ac2efd236da9c8608b8685b2d': 'v6',
+	'6c9f6d3981483f8e9433df99d1947b27': 'v7',
+	'89b13a7af83337c3aad153b717e52360': 'v8'
 }
 
 # get columns and data types for a given table
@@ -177,7 +181,7 @@ def __request_login_params_tui():
 	print "\nPlease enter the required login parameters:"
 	try:
 		login.host = __prompted_input("host ['' = non-TCP/IP]: ", '')
-		login.database = __prompted_input("database [gnumed_v6]: ", 'gnumed_v6')
+		login.database = __prompted_input("database [gnumed_v8]: ", 'gnumed_v8')
 		login.user = __prompted_input("user name: ", '')
 		login.password = getpass.getpass("password (not shown): ")
 		login.port = __prompted_input("port [5432]: ", 5432)
@@ -201,12 +205,11 @@ def __request_login_params_gui_wx():
 
 	# Let's launch the login dialog
 	# if wx was not initialized /no main App loop, an exception should be raised anyway
-	import gmLoginDialog
-	dlg = gmLoginDialog.LoginDialog(None, -1)
+	import gmAuthWidgets
+	dlg = gmAuthWidgets.cLoginDialog(None, -1)
 	dlg.ShowModal()
 	login = dlg.panel.GetLoginInfo()
 	dlg.Destroy()
-	del gmLoginDialog
 
 	#if user cancelled or something else went wrong, raise an exception
 	if login is None:
@@ -287,9 +290,36 @@ def set_default_login(login=None):
 # =======================================================================
 # netadata API
 # =======================================================================
-def database_schema_compatible(link_obj=None, version=None):
+def sanity_check_database_settings():
+	_log.Log(gmLog.lInfo, 'checking database settings')
+	settings = {
+		u'allow_system_table_mods': [u'off', u'system breakage'],
+		u'fsync': [u'on', u'data loss/corruption'],
+		u'full_page_writes': [u'on', u'data loss/corruption'],
+		u'password_encryption': [u'on', u'breach of confidentiality'],
+		u'regex_flavor': [u'advanced', u'query breakage'],
+		u'synchronous_commit': [u'on', u'data loss/corruption'],
+		u'sql_inheritance': [u'on', u'query breakage, data loss/corruption']
+	}
+
+	cmd = u"select name, setting from pg_settings where name in %(settings)s"
+	rows, idx = run_ro_queries(queries = [{'cmd': cmd, 'args': {'settings': tuple(settings.keys())}}])
+
+	all_good = True
+	msg = []
+	for row in rows:
+		if row[1] != settings[row[0]][0]:
+			all_good = False
+			msg.append(' option [%s] = [%s] risks "%s"' % (row[0], row[1], settings[row[0]][1]))
+			_log.Log(gmLog.lWarn, 'PG option [%s] set to [%s], expected [%s], risk: <%s>' % (row[0], row[1], settings[row[0]][0], settings[row[0]][1]))
+
+	if not all_good:
+		return u'\n'.join(msg)
+
+	return True
+#------------------------------------------------------------------------
+def database_schema_compatible(link_obj=None, version=None, verbose=True):
 	expected_hash = known_schema_hashes[version]
-#	rows, idx = run_ro_queries(link_obj = link_obj, queries = [{'cmd': u'select md5(gm_concat_table_structure()) as md5'}])
 	if version == 'devel':
 		args = {'ver': '9999'}
 	else:
@@ -305,6 +335,10 @@ def database_schema_compatible(link_obj=None, version=None):
 		_log.Log(gmLog.lErr, 'database schema version mismatch')
 		_log.Log(gmLog.lErr, 'expected: %s (%s)' % (version, expected_hash))
 		_log.Log(gmLog.lErr, 'detected: %s (%s)' % (get_schema_version(link_obj=link_obj), rows[0]['md5']))
+		if verbose:
+			_log.Log(gmLog.lData, 'schema dump follows:')
+			for line in get_schema_structure(link_obj=link_obj).split():
+				_log.Log(gmLog.lData, line)
 		return False
 	_log.Log(gmLog.lInfo, 'detected schema version [%s], hash [%s]' % (map_schema_hash2version[rows[0]['md5']], rows[0]['md5']))
 	return True
@@ -366,8 +400,15 @@ def get_col_indices(cursor = None):
 	col_indices = {}
 	col_index = 0
 	for col_desc in cursor.description:
-		col_indices[col_desc[0]] = col_index
+		col_name = col_desc[0]
+		# a query like "select 1,2;" will return two columns of the same name !
+		# hence adjust to that, note, however, that dict-style access won't work
+		# on results of such queries ...
+		if col_indices.has_key(col_name):
+			col_name = '%s_%s' % (col_name, col_index)
+		col_indices[col_name] = col_index
 		col_index += 1
+
 	return col_indices
 #------------------------------------------------------------------------
 def get_col_defs(link_obj=None, schema='public', table=None):
@@ -394,8 +435,164 @@ def get_col_names(link_obj=None, schema='public', table=None):
 		cols.append(row[0])
 	return cols
 # =======================================================================
-# query runners
+# query runners and helpers
 # =======================================================================
+def is_pg_interval(candidate=None):
+	cmd = u'select %(candidate)s::interval'
+	try:
+		rows, idx = run_ro_queries(queries = [{'cmd': cmd, 'args': {'candidate': candidate}}])
+		return True
+	except:
+		cmd = u'select %(candidate)s::text::interval'
+		try:
+			rows, idx = run_ro_queries(queries = [{'cmd': cmd, 'args': {'candidate': candidate}}])
+			return True
+		except:
+			return False
+#------------------------------------------------------------------------
+def bytea2file(data_query=None, filename=None, chunk_size=0, data_size=None, data_size_query=None):
+	outfile = file(filename, 'wb')
+	result = bytea2file_object(data_query=data_query, file_obj=outfile, chunk_size=chunk_size, data_size=data_size, data_size_query=data_size_query)
+	outfile.close()
+	return result
+#------------------------------------------------------------------------
+def bytea2file_object(data_query=None, file_obj=None, chunk_size=0, data_size=None, data_size_query=None):
+	"""Store data from a bytea field into a file.
+
+	<data_query>
+	- dict {'cmd': ..., 'args': ...}
+	- 'cmd' must be unicode containing "... substring(data from %(start)s for %(size)s) ..."
+	- 'args' must be a dict
+	- must return one row with one field of type bytea
+	<file>
+	- must be a file like Python object
+	<data_size>
+	- integer of the total size of the expected data or None
+	<data_size_query>
+	- dict {'cmd': ..., 'args': ...}
+	- cmd must be unicode
+	- must return one row with one field with the octet_length() of the data field
+	- used only when <data_size> is None
+	"""
+	if data_size == 0:
+		return True
+
+	# If the client sets an encoding other than the default we
+	# will receive encoding-parsed data which isn't the binary
+	# content we want. Hence we need to get our own connection.
+	# It must be a read-write one so that we don't affect the
+	# encoding for other users of the shared read-only
+	# connections.
+	# Actually, encodings shouldn't be applied to binary data
+	# (eg. bytea types) in the first place but that is only
+	# reported to be fixed > v7.4.
+	# further tests reveal that at least on PG 8.0 this bug still
+	# manifests itself
+	conn = get_raw_connection()
+
+	if data_size is None:
+		rows, idx = run_ro_queries(link_obj = conn, queries = [data_size_query])
+		data_size = rows[0][0]
+		if data_size in [None, 0]:
+			conn.close()
+			return True
+
+	_log.Log(gmLog.lData, 'expecting bytea data of size: [%s] bytes' % data_size)
+	_log.Log(gmLog.lData, 'using chunk size of: [%s] bytes' % chunk_size)
+
+	# chunk size of 0 means "retrieve whole field at once"
+	if chunk_size == 0:
+		chunk_size = data_size
+		_log.Log(gmLog.lData, 'chunk size [0] bytes: retrieving all data at once')
+
+	# Windoze sucks: it can't transfer objects of arbitrary size,
+	# anyways, we need to split the transfer,
+	# however, only possible if postgres >= 7.2
+	needed_chunks, remainder = divmod(data_size, chunk_size)
+	_log.Log(gmLog.lData, 'chunks to retrieve: [%s]' % needed_chunks)
+	_log.Log(gmLog.lData, 'remainder to retrieve: [%s] bytes' % remainder)
+
+	# retrieve chunks, skipped if data size < chunk size,
+	# does this not carry the danger of cutting up multi-byte escape sequences ?
+	# no, since bytea is binary,
+	# yes, since in bytea there are *some* escaped values, still
+	# no, since those are only escaped during *transfer*, not on-disk, hence
+	# only complete escape sequences are put on the wire
+	for chunk_id in range(needed_chunks):
+		chunk_start = (chunk_id * chunk_size) + 1
+		data_query['args']['start'] = chunk_start
+		data_query['args']['size'] = chunk_size
+		try:
+			rows, idx = run_ro_queries(link_obj=conn, queries=[data_query])
+		except:
+			_log.Log(gmLog.lErr, 'cannot retrieve chunk [%s/%s], size [%s], try decreasing chunk size' % (chunk_id+1, needed_chunks, chunk_size))
+			conn.close()
+			raise
+		# it would be a fatal error to see more than one result as ids are supposed to be unique
+		file_obj.write(str(rows[0][0]))
+
+	# retrieve remainder
+	if remainder > 0:
+		chunk_start = (needed_chunks * chunk_size) + 1
+		data_query['args']['start'] = chunk_start
+		data_query['args']['size'] = remainder
+		try:
+			rows, idx = run_ro_queries(link_obj=conn, queries=[data_query])
+		except:
+			_log.Log(gmLog.lErr, 'cannot retrieve remaining [%s] bytes' % remainder)
+			conn.close()
+			raise
+		# it would be a fatal error to see more than one result as ids are supposed to be unique
+		file_obj.write(str(rows[0][0]))
+
+	conn.close()
+	return True
+#------------------------------------------------------------------------
+def file2bytea(query=None, filename=None, args=None, conn=None):
+	"""Store data from a file into a bytea field.
+
+	The query must:
+	- be in unicode
+	- contain a format spec identifying the row (eg a primary key) matching <args>
+	- contain a format spec %(data)s::bytea
+	"""
+	# read data from file
+	infile = file(filename, "rb")
+	data_as_byte_string = infile.read()
+	infile.close()
+	if args is None:
+		args = {}
+	args['data'] = buffer(data_as_byte_string)
+	del(data_as_byte_string)
+
+	# insert the data
+	if conn is None:
+		conn = get_raw_connection()
+	run_rw_queries(link_obj=conn, queries = [{'cmd': query, 'args': args}], end_tx=True)
+	conn.close()
+
+	return
+#------------------------------------------------------------------------
+def sanitize_pg_regex(expression=None, escape_all=False):
+	"""Escape input for use in a PostgreSQL regular expression.
+
+	If a fragment comes from user input and is to be used
+	as a regular expression we need to make sure it doesn't
+	contain invalid regex patterns such as unbalanced ('s.
+
+	<escape_all>
+		True: try to escape *all* metacharacters
+		False: only escape those which render the regex invalid
+	"""
+	return expression.replace (
+			'(', '\('
+		).replace (
+			')', '\)'
+		).replace (
+			'[', '\['
+		)
+		#']', '\]',			# not needed
+#------------------------------------------------------------------------
 def run_ro_queries(link_obj=None, queries=None, verbose=False, return_data=True, get_col_idx=False):
 	"""Run read-only queries.
 
@@ -407,7 +604,6 @@ def run_ro_queries(link_obj=None, queries=None, verbose=False, return_data=True,
 		]
 	"""
 	if isinstance(link_obj, dbapi._psycopg.cursor):
-		_log.Log(gmLog.lData, 'link object: %s' % link_obj)
 		curs = link_obj
 		curs_close = __noop
 		conn_close = __noop
@@ -436,7 +632,7 @@ def run_ro_queries(link_obj=None, queries=None, verbose=False, return_data=True,
 		try:
 			args = query['args']
 		except KeyError:
-			args = (None,)
+			args = None
 		try:
 			curs.execute(query['cmd'], args)
 			if verbose:
@@ -449,7 +645,6 @@ def run_ro_queries(link_obj=None, queries=None, verbose=False, return_data=True,
 			conn_close()
 			_log.Log(gmLog.lErr, 'query failed: [%s]' % curs.query)
 			_log.Log(gmLog.lErr, 'PG status message: %s' % curs.statusmessage)
-			_log.flush()
 			raise
 
 	data = None
@@ -494,6 +689,7 @@ def run_rw_queries(link_obj=None, queries=None, end_tx=False, return_data=None,
 		  transaction is properly finalized
 		- if link_obj is a cursor we CANNOT finalize the
 		  transaction because we would need the connection for that
+		- if link_obj is None <end_tx> will, of course, always be True
 
 	<return_data>
 		- if true, the returned data will include the rows
@@ -545,7 +741,7 @@ def run_rw_queries(link_obj=None, queries=None, end_tx=False, return_data=None,
 		try:
 			args = query['args']
 		except KeyError:
-			args = (None,)
+			args = None
 		try:
 			curs.execute(query['cmd'], args)
 		except:
@@ -616,7 +812,7 @@ def get_raw_connection(dsn=None, verbose=False):
 			raise cAuthenticationError, (dsn, v), tb
 		if str(v).find('authentication failed for user') != -1:
 			raise cAuthenticationError, (dsn, v), tb
-		if re.search('user ".*" does not exist', str(v)) is not None:
+		if regex.search('user ".*" does not exist', str(v)) is not None:
 			raise cAuthenticationError, (dsn, v), tb
 		raise
 
@@ -715,6 +911,11 @@ def get_connection(dsn=None, readonly=True, encoding=None, verbose=False, pooled
 	cmd = 'set session characteristics as transaction %s' % access_mode
 	curs.execute(cmd)
 
+	# 6) SQL inheritance mode
+	_log.Log(gmLog.lData, 'sql_inheritance [on]')
+	cmd = 'set sql_inheritance to on'
+	curs.execute(cmd)
+
 	# version string
 	global postgresql_version_string
 	if postgresql_version_string is None:
@@ -798,8 +999,12 @@ class cAdapterMxDateTime(object):
 psycopg2.extensions.register_type(psycopg2.extensions.UNICODE)
 psycopg2.extensions.register_type(psycopg2._psycopg.UNICODEARRAY)
 
-# properly adapt *tuples* into (a, b, c, ...) in "... IN ..." queries
-psycopg2.extensions.register_adapter(tuple, psycopg2.extras.SQL_IN)
+try:
+	# properly adapt *tuples* into (a, b, c, ...) in "... IN ..." queries
+	psycopg2.extensions.register_adapter(tuple, psycopg2.extras.SQL_IN)
+except AttributeError:
+	# only needed in psycopg2 < 0.2.6
+	pass
 
 # do NOT adapt *lists* to "... IN (*) ..." syntax because we want
 # them adapted to "... ARRAY()..." so we can support PG arrays
@@ -831,7 +1036,7 @@ if __name__ == "__main__":
 			print ' ', t
 			print ' ', v
 
-		dsn = 'dbname=gnumed_v6'
+		dsn = 'dbname=gnumed_v8'
 		try:
 			conn = get_connection(dsn=dsn)
 		except cAuthenticationError:
@@ -840,7 +1045,7 @@ if __name__ == "__main__":
 			print ' ', t
 			print ' ', v
 
-		dsn = 'dbname=gnumed_v6 user=abc'
+		dsn = 'dbname=gnumed_v8 user=abc'
 		try:
 			conn = get_connection(dsn=dsn)
 		except cAuthenticationError:
@@ -849,7 +1054,7 @@ if __name__ == "__main__":
 			print ' ', t
 			print ' ', v
 
-		dsn = 'dbname=gnumed_v6 user=any-doc'
+		dsn = 'dbname=gnumed_v8 user=any-doc'
 		try:
 			conn = get_connection(dsn=dsn)
 		except cAuthenticationError:
@@ -858,7 +1063,7 @@ if __name__ == "__main__":
 			print ' ', t
 			print ' ', v
 
-		dsn = 'dbname=gnumed_v6 user=any-doc password=abc'
+		dsn = 'dbname=gnumed_v8 user=any-doc password=abc'
 		try:
 			conn = get_connection(dsn=dsn)
 		except cAuthenticationError:
@@ -867,13 +1072,13 @@ if __name__ == "__main__":
 			print ' ', t
 			print ' ', v
 
-		dsn = 'dbname=gnumed_v6 user=any-doc password=any-doc'
+		dsn = 'dbname=gnumed_v8 user=any-doc password=any-doc'
 		conn = get_connection(dsn=dsn, readonly=True)
 
-		dsn = 'dbname=gnumed_v6 user=any-doc password=any-doc'
+		dsn = 'dbname=gnumed_v8 user=any-doc password=any-doc'
 		conn = get_connection(dsn=dsn, readonly=False)
 
-		dsn = 'dbname=gnumed_v6 user=any-doc password=any-doc'
+		dsn = 'dbname=gnumed_v8 user=any-doc password=any-doc'
 		encoding = 'foo'
 		try:
 			conn = get_connection(dsn=dsn, encoding=encoding)
@@ -905,7 +1110,7 @@ if __name__ == "__main__":
 	def test_ro_queries():
 		print "testing run_ro_queries()"
 
-		dsn = 'dbname=gnumed_v6 user=any-doc password=any-doc'
+		dsn = 'dbname=gnumed_v8 user=any-doc password=any-doc'
 		conn = get_connection(dsn, readonly=True)
 
 		data, idx = run_ro_queries(link_obj=conn, queries=[{'cmd': u'select version()'}], return_data=True, get_col_idx=True, verbose=True)
@@ -1014,17 +1219,116 @@ if __name__ == "__main__":
 		print pool.getconn()
 		print type(pool.getconn())
 	#--------------------------------------------------------------------
+	def test_list_args():
+		dsn = get_default_dsn()
+		conn = get_connection(dsn, readonly=True)
+		curs = conn.cursor()
+		curs.execute('select * from clin.clin_narrative where narrative = %s', ['a'])
+	#--------------------------------------------------------------------
+	def test_sanitize_pg_regex():
+		tests = [
+			['(', '\\(']
+			, ['[', '\\[']
+			, [')', '\\)']
+		]
+		for test in tests:
+			result = sanitize_pg_regex(test[0])
+			if result != test[1]:
+				print 'ERROR: sanitize_pg_regex(%s) returned "%s", expected "%s"' % (test[0], result, test[1])
+	#--------------------------------------------------------------------
+	def test_is_pg_interval():
+		status = True
+		tests = [
+			[None, True],		# None == NULL == succeeds !
+			[1, True],
+			['1', True],
+			['abc', False]
+		]
+
+		if not is_pg_interval():
+			print 'ERROR: is_pg_interval() returned "False", expected "True"'
+			status = False
+
+		for test in tests:
+			result = is_pg_interval(test[0])
+			if result != test[1]:
+				print 'ERROR: is_pg_interval(%s) returned "%s", expected "%s"' % (test[0], result, test[1])
+				status = False
+
+		return status
+	#--------------------------------------------------------------------
 	# run tests
 #	test_get_connection()
 #	test_exceptions()
 #	test_ro_queries()
 #	test_request_dsn()
 #	test_set_encoding()
-	test_connection_pool()
-	print "tests ran successfully"
+#	test_connection_pool()
+#	test_list_args()
+#	test_sanitize_pg_regex()
+	test_is_pg_interval()
 
 # =======================================================================
 # $Log: gmPG2.py,v $
+# Revision 1.63.2.1  2008/01/13 01:09:05  ncq
+# - remove misplaced flush()
+#
+# Revision 1.63  2007/12/06 13:07:19  ncq
+# - add v8 schema hash
+#
+# Revision 1.62  2007/12/04 16:14:24  ncq
+# - use gmAuthWidgets
+#
+# Revision 1.61  2007/12/04 15:11:20  ncq
+# - sanity_check_database_settings()
+# - force sql_inheritance to on after connect
+#
+# Revision 1.60  2007/11/09 14:39:10  ncq
+# - log schema dump if verbose on failed version detection
+#
+# Revision 1.59  2007/10/25 16:41:30  ncq
+# - is_pg_interval() + test
+#
+# Revision 1.58  2007/10/22 12:37:59  ncq
+# - default db change
+#
+# Revision 1.57  2007/09/24 18:29:42  ncq
+# - select 1,2; will return two columns with the same name !
+#   hence, mapping names to column indices in a dict will not work :-(
+#   fix breakage but don't really support it, either
+#
+# Revision 1.56  2007/09/18 22:53:26  ncq
+# - enhance file2bytea to accept conn argument
+#
+# Revision 1.55  2007/09/17 21:46:28  ncq
+# - make hash for v7 known
+#
+# Revision 1.54  2007/08/31 14:28:29  ncq
+# - improved docs
+#
+# Revision 1.53  2007/08/08 21:25:39  ncq
+# - improve bytea2file()
+#
+# Revision 1.52  2007/07/22 09:03:33  ncq
+# - bytea2file(_object)()
+# - file2bytea()
+#
+# Revision 1.51  2007/07/03 15:53:50  ncq
+# - import re as regex
+# - sanitize_pg_regex() and test
+#
+# Revision 1.50  2007/06/28 12:35:38  ncq
+# - optionalize SQL IN tuple adaptation as it's now builtin to 0.2.6 psycopg2
+#
+# Revision 1.49  2007/06/15 10:24:24  ncq
+# - add a test to the test suite
+#
+# Revision 1.48  2007/06/12 16:02:12  ncq
+# - fix case when there are no args for execute()
+#
+# Revision 1.47  2007/06/11 20:24:18  ncq
+# - bump database version
+#
 # Revision 1.46  2007/05/07 16:45:12  ncq
 # - add v6 schema hash
 #
