@@ -12,9 +12,10 @@ not being dispatched. It would allow to do messenging house keeping as well.
 # to anybody else.
 #=============================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/pycommon/gmSignals.py,v $
-__version__ = "$Revision: 1.15 $"
+__version__ = "$Revision: 1.18 $"
 __author__  = "H. Herb <hherb@gnumed.net>"
 
+
 #=============================================================
 def popup_notice():
 	"a notice of general interest has been received"
@@ -24,22 +25,9 @@ def popup_alert():
 	"an important notice of general ineterest has been received"
 	return 'popup_alert'
 
-def statustext():
-	return 'statustext'
-
 #-------------------------------------------------------------
 # clinical signals
 #-------------------------------------------------------------
-# allergies
-def allg_mod_db():
-	"""Announce modification of allergy row into/from backend."""
-	return 'allg_mod_db'
-
-def allergy_updated():
-	"""Announce allergy cache update to interested parties."""
-	return 'allergy_updated'
-
-#------------------------------------------
 # vaccinations
 def vacc_mod_db():
 	"""table vaccination"""
@@ -94,6 +82,8 @@ def clin_item_updated():
 	"""Frontend signal for clin_root_item cache update."""
 	return 'clin_item_updated'
 #-------------------------------------------------------------
+# patient_locked, patient_unlocked
+
 def pre_patient_selection():
 	"""the currently active patient is about to be changed"""
 	return 'pre_patient_selection'
@@ -130,15 +120,6 @@ def application_closing():
 def application_init():
 	"an application is starting"
 	return "application_init"
-
-#-------------------------------------------------------------
-def display_widget():
-	"""Request a widget to be displayed.
-
-	- name: the widget name
-	- additional keywords: widget specific
-	"""
-	return "display_widget"
 #-------------------------------------------------------------
 def user_error ():
 	"an error of interest to the user"
@@ -227,6 +208,15 @@ if __name__ == "__main__":
 
 #======================================================================
 # $Log: gmSignals.py,v $
+# Revision 1.18  2007/10/25 12:26:47  ncq
+# - allergy signals are gone
+#
+# Revision 1.17  2007/08/12 00:06:38  ncq
+# - remove signals that aren't used from here anymore
+#
+# Revision 1.16  2007/07/13 12:09:16  ncq
+# - add comment
+#
 # Revision 1.15  2007/03/02 15:30:46  ncq
 # - add statustext()
 #
