@@ -2,14 +2,14 @@
 __doc__ = """GNUmed general tools."""
 
 #===========================================================================
-# $Id: gmTools.py,v 1.29 2007/05/17 15:12:59 ncq Exp $
+# $Id: gmTools.py,v 1.43 2007/11/28 13:59:23 ncq Exp $
 # $Source: /sources/gnumed/gnumed/gnumed/client/pycommon/gmTools.py,v $
-__version__ = "$Revision: 1.29 $"
+__version__ = "$Revision: 1.43 $"
 __author__ = "K. Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL (details at http://www.gnu.org)"
 
 # std libs
-import datetime as pydt, re as regex, sys, os, os.path
+import datetime as pydt, re as regex, sys, os, os.path, csv, tempfile
 
 
 # GNUmed libs
@@ -18,12 +18,11 @@ if __name__ == '__main__':
 from Gnumed.pycommon import gmLog, gmBorg
 
 
+_ = lambda x:x
+
 _log = gmLog.gmDefLog
 _log.Log(gmLog.lInfo, __version__)
 
-
-ooo_start_cmd = 'oowriter -accept="socket,host=localhost,port=2002;urp;"'
-
 # CAPitalization modes:
 (
 	CAPS_NONE,					# don't touch it
@@ -38,6 +37,19 @@ default_mail_sender = u'gnumed@gmx.net'
 default_mail_receiver = u'gnumed-devel@gnu.org'
 default_mail_server = u'mail.gmx.net'
 
+
+#===========================================================================
+def utf_8_encoder(unicode_csv_data):
+	for line in unicode_csv_data:
+		yield line.encode('utf-8')
+
+def unicode_csv_reader(unicode_csv_data, dialect=csv.excel, **kwargs):
+	# csv.py doesn't do Unicode; encode temporarily as UTF-8:
+	csv_reader = csv.reader(utf_8_encoder(unicode_csv_data), dialect=dialect, **kwargs)
+
+	for row in csv_reader:
+		# decode UTF-8 back to Unicode, cell by cell:
+		yield [unicode(cell, 'utf-8') for cell in row]
 #===========================================================================
 def handle_uncaught_exception(t, v, tb):
 
@@ -51,11 +63,9 @@ def handle_uncaught_exception(t, v, tb):
 	sys.__excepthook__(t,v,tb)
 
 #===========================================================================
-class cPaths(gmBorg.cBorg):
+class gmPaths(gmBorg.cBorg):
 
 	def __init__(self, app_name=None, wx=None):
-		gmBorg.cBorg.__init__(self)
-
 		try:
 			self.already_inited
 			return
@@ -126,8 +136,9 @@ class cPaths(gmBorg.cBorg):
 		return True
 	#--------------------------------------
 	def __log_paths(self):
-		_log.Log(gmLog.lData, 'local base dir: %s' % self.local_base_dir)
-		_log.Log(gmLog.lData, 'working dir: %s' % self.working_dir)
+		_log.Log(gmLog.lData, 'local application base dir: %s' % self.local_base_dir)
+		_log.Log(gmLog.lData, 'current working dir: %s' % self.working_dir)
+		_log.Log(gmLog.lData, 'user home dir: %s' % os.path.expanduser('~'))
 		_log.Log(gmLog.lData, 'user-specific config dir: %s' % self.user_config_dir)
 		_log.Log(gmLog.lData, 'system-wide config dir: %s' % self.system_config_dir)
 		_log.Log(gmLog.lData, 'system-wide application data dir: %s' % self.system_app_data_dir)
@@ -170,7 +181,13 @@ class cPaths(gmBorg.cBorg):
 
 	system_app_data_dir = property(_get_system_app_data_dir, _set_system_app_data_dir)
 #===========================================================================
-def send_mail(sender=None, receiver=None, message=None, server=None, auth=None, debug=False):
+def send_mail(sender=None, receiver=None, message=None, server=None, auth=None, debug=False, subject=None, encoding='latin1'):
+	"""Send an E-Mail.
+
+	<debug>: see smtplib.set_debuglevel()
+	<auth>: {'user': ..., 'password': ...}
+	<receiver>: a list of email addresses
+	"""
 	if message is None:
 		return False
 	message = message.lstrip().lstrip('\r\n').lstrip()
@@ -184,12 +201,22 @@ def send_mail(sender=None, receiver=None, message=None, server=None, auth=None,
 	if server is None:
 		server = default_mail_server
 
+	if subject is None:
+		subject = u'gmTools.py: send_mail() test'
+
+	body = u"""From: %s
+To: %s
+Subject: %s
+
+%s
+""" % (sender, u', '.join(receiver), subject, message)
+
 	import smtplib
 	session = smtplib.SMTP(server)
 	session.set_debuglevel(debug)
 	if auth is not None:
 		session.login(auth['user'], auth['password'])
-	refused = session.sendmail(sender, receiver, message)
+	refused = session.sendmail(sender, receiver, body.encode(encoding))
 	session.quit()
 	if len(refused) != 0:
 		_log.Log(gmLog.lErr, "refused recipients: %s" % refused)
@@ -204,9 +231,36 @@ def mkdir(directory=None):
 		if (e.errno == 17) and not os.path.isdir(directory):
 			raise
 	return True
+#---------------------------------------------------------------------------
+def get_unique_filename(prefix=None, suffix=None, dir=None):
+	"""This introduces a race condition between the file.close() and
+	actually using the filename.
+
+	The file will not exist after calling this function.
+	"""
+	kwargs = {'dir': dir}
+
+	if prefix is None:
+		kwargs['prefix'] = 'gnumed-'
+	else:
+		kwargs['prefix'] = prefix
+
+	if suffix is None:
+		kwargs['suffix'] = '.tmp'
+	else:
+		if not suffix.startswith('.'):
+			suffix = '.' + suffix
+		kwargs['suffix'] = suffix
+
+	f = tempfile.NamedTemporaryFile(**kwargs)
+	filename = f.name
+	f.close()
+
+	return filename
 #===========================================================================
 def import_module_from_directory(module_path=None, module_name=None):
 	"""Import a module from any location."""
+
 	if module_path not in sys.path:
 		_log.Log(gmLog.lInfo, 'appending to sys.path: [%s]' % module_path)
 		sys.path.append(module_path)
@@ -221,7 +275,7 @@ def import_module_from_directory(module_path=None, module_name=None):
 		module = __import__(module_name)
 		_log.Log(gmLog.lInfo, 'imported module [%s] as [%s]' % (module_name, module))
 	except StandardError:
-		_log.LogException('cannot __import__() module [%s] from [%s]' % (module_name, module_path), exc_info=sys.exc_info(), verbose=0)
+		_log.LogException('cannot __import__() module [%s] from [%s]' % (module_name, module_path), verbose=0)
 		if remove_path:
 			sys.path.remove(module_path)
 		raise
@@ -231,49 +285,6 @@ def import_module_from_directory(module_path=None, module_name=None):
 
 	return module
 #===========================================================================
-def open_uri_in_ooo(filename=None):
-	"""Connect to OOo and open document.
-
-	<filename> must be absolute
-
-	Actually, this whole thing is redundant. We should just
-	use call_editor_on_mimetype(filename). The advantage of
-	this is that we can connect to a single OOo *server*.
-
-	You will need to start an OOo server before using this:
-
-		oowriter -accept="socket,host=localhost,port=2002;urp;"
-	"""
-	try:
-		import uno
-		from com.sun.star.connection import NoConnectException as UnoNoConnectException
-	except ImportError:
-		_log.Log(gmLog.lInfo, 'open_uri_in_ooo(): cannot import UNO, OpenOffice and/or UNO installed ?')
-		# fail gracefully if OOo/UNO isn't insalled
-		return False
-
-	# failing early is good
-	document_uri = uno.systemPathToFileUrl(filename)
-
-	resolver_uri = "com.sun.star.bridge.UnoUrlResolver"
-	remote_context_uri = "uno:socket,host=localhost,port=2002;urp;StarOffice.ComponentContext"
-	ooo_desktop_uri = "com.sun.star.frame.Desktop"
-
-	local_context = uno.getComponentContext()
-	uri_resolver = local_context.ServiceManager.createInstanceWithContext(resolver_uri, local_context)
-
-	try:
-		remote_context = uri_resolver.resolve(remote_context_uri)
-	except UnoNoConnectException:
-		_log.Log(gmLog.lInfo, 'Cannot connect to OOo server. Trying to start one with: [%s]' % ooo_start_cmd)
-		os.system(ooo_start_cmd)
-		remote_context	= uri_resolver.resolve(remote_context_uri)
-
-	ooo_desktop	= remote_context.ServiceManager.createInstanceWithContext(ooo_desktop_uri, remote_context)
-	document = ooo_desktop.loadComponentFromURL(document_uri, "_blank", 0, ())
-
-	return True
-#===========================================================================
 # FIXME: should this not be in gmTime or some such?
 # close enough on average
 days_per_year = 365
@@ -283,51 +294,57 @@ days_per_week = 7
 def str2interval(str_interval=None):
 
 	# "(~)35(yYjJaA)"	- at age 35 years
-	if regex.match('^(\s|\t)*~*(\s|\t)*\d+(y|Y|j|J|a|A|\s|\t)*$', str_interval):
-		return pydt.timedelta(days = (int(regex.findall('\d+', str_interval)[0]) * days_per_year))
+	if regex.match(u'^(\s|\t)*~*(\s|\t)*\d+(y|Y|j|J|a|A|\s|\t)*$', str_interval, flags = regex.LOCALE | regex.UNICODE):
+		return pydt.timedelta(days = (int(regex.findall(u'\d+', str_interval, flags = regex.LOCALE | regex.UNICODE)[0]) * days_per_year))
 
 	# "(~)12mM" - at age 12 months
-	if regex.match('^(\s|\t)*~*(\s|\t)*\d+(\s|\t)*(m|M)+(\s|\t)*$', str_interval):
-		years, months = divmod(int(regex.findall('\d+', str_interval)[0]), 12)
+	if regex.match(u'^(\s|\t)*~*(\s|\t)*\d+(\s|\t)*(m|M)+(\s|\t)*$', str_interval, flags = regex.LOCALE | regex.UNICODE):
+		years, months = divmod (
+			int(regex.findall(u'\d+', str_interval, flags = regex.LOCALE | regex.UNICODE)[0]),
+			12
+		)
 		return pydt.timedelta(days = ((years * days_per_year) + (months * days_per_month)))
 
 	# weeks
-	if regex.match('^(\s|\t)*~*(\s|\t)*\d+(\s|\t)*(w|W)+(\s|\t)*$', str_interval):
-		return pydt.timedelta(weeks = int(regex.findall('\d+', str_interval)[0]))
+	if regex.match(u'^(\s|\t)*~*(\s|\t)*\d+(\s|\t)*(w|W)+(\s|\t)*$', str_interval, flags = regex.LOCALE | regex.UNICODE):
+		return pydt.timedelta(weeks = int(regex.findall(u'\d+', str_interval, flags = regex.LOCALE | regex.UNICODE)[0]))
 
 	# days
-	if regex.match('^(\s|\t)*~*(\s|\t)*\d+(\s|\t)*(d|D|t|T)+(\s|\t)*$', str_interval):
-		return pydt.timedelta(days = int(regex.findall('\d+', str_interval)[0]))
+	if regex.match(u'^(\s|\t)*~*(\s|\t)*\d+(\s|\t)*(d|D|t|T)+(\s|\t)*$', str_interval, flags = regex.LOCALE | regex.UNICODE):
+		return pydt.timedelta(days = int(regex.findall(u'\d+', str_interval, flags = regex.LOCALE | regex.UNICODE)[0]))
 
 	# hours
-	if regex.match('^(\s|\t)*~*(\s|\t)*\d+(\s|\t)*(h|H)+(\s|\t)*$', str_interval):
-		return pydt.timedelta(hours = int(regex.findall('\d+', str_interval)[0]))
+	if regex.match(u'^(\s|\t)*~*(\s|\t)*\d+(\s|\t)*(h|H)+(\s|\t)*$', str_interval, flags = regex.LOCALE | regex.UNICODE):
+		return pydt.timedelta(hours = int(regex.findall(u'\d+', str_interval, flags = regex.LOCALE | regex.UNICODE)[0]))
 
 	# x/12 - months
-	if regex.match('^(\s|\t)*~*(\s|\t)*\d+(\s|\t)*/(\s|\t)*12(\s|\t)*$', str_interval):
-		years, months = divmod(int(regex.findall('\d+', str_interval)[0]), 12)
+	if regex.match(u'^(\s|\t)*~*(\s|\t)*\d+(\s|\t)*/(\s|\t)*12(\s|\t)*$', str_interval, flags = regex.LOCALE | regex.UNICODE):
+		years, months = divmod (
+			int(regex.findall(u'\d+', str_interval, flags = regex.LOCALE | regex.UNICODE)[0]),
+			12
+		)
 		return pydt.timedelta(days = ((years * days_per_year) + (months * days_per_month)))
 
 	# x/52 - weeks
-	if regex.match('^(\s|\t)*~*(\s|\t)*\d+(\s|\t)*/(\s|\t)*52(\s|\t)*$', str_interval):
+	if regex.match(u'^(\s|\t)*~*(\s|\t)*\d+(\s|\t)*/(\s|\t)*52(\s|\t)*$', str_interval, flags = regex.LOCALE | regex.UNICODE):
 #		return pydt.timedelta(days = (int(regex.findall('\d+', str_interval)[0]) * days_per_week))
-		return pydt.timedelta(weeks = int(regex.findall('\d+', str_interval)[0]))
+		return pydt.timedelta(weeks = int(regex.findall(u'\d+', str_interval, flags = regex.LOCALE | regex.UNICODE)[0]))
 
 	# x/7 - days
-	if regex.match('^(\s|\t)*~*(\s|\t)*\d+(\s|\t)*/(\s|\t)*7(\s|\t)*$', str_interval):
-		return pydt.timedelta(days = int(regex.findall('\d+', str_interval)[0]))
+	if regex.match(u'^(\s|\t)*~*(\s|\t)*\d+(\s|\t)*/(\s|\t)*7(\s|\t)*$', str_interval, flags = regex.LOCALE | regex.UNICODE):
+		return pydt.timedelta(days = int(regex.findall(u'\d+', str_interval, flags = regex.LOCALE | regex.UNICODE)[0]))
 
 	# x/24 - hours
-	if regex.match('^(\s|\t)*~*(\s|\t)*\d+(\s|\t)*/(\s|\t)*24(\s|\t)*$', str_interval):
-		return pydt.timedelta(hours = int(regex.findall('\d+', str_interval)[0]))
+	if regex.match(u'^(\s|\t)*~*(\s|\t)*\d+(\s|\t)*/(\s|\t)*24(\s|\t)*$', str_interval, flags = regex.LOCALE | regex.UNICODE):
+		return pydt.timedelta(hours = int(regex.findall(u'\d+', str_interval, flags = regex.LOCALE | regex.UNICODE)[0]))
 
 	# x/60 - minutes
-	if regex.match('^(\s|\t)*~*(\s|\t)*\d+(\s|\t)*/(\s|\t)*60(\s|\t)*$', str_interval):
-		return pydt.timedelta(minutes = int(regex.findall('\d+', str_interval)[0]))
+	if regex.match(u'^(\s|\t)*~*(\s|\t)*\d+(\s|\t)*/(\s|\t)*60(\s|\t)*$', str_interval, flags = regex.LOCALE | regex.UNICODE):
+		return pydt.timedelta(minutes = int(regex.findall(u'\d+', str_interval, flags = regex.LOCALE | regex.UNICODE)[0]))
 
 	# nYnM - years, months
-	if regex.match('^(\s|\t)*~*(\s|\t)*\d+(y|Y|j|J|a|A|\s|\t)+\d+(\s|\t)*(m|M)+(\s|\t)*$', str_interval):
-		parts = regex.findall('\d+', str_interval)
+	if regex.match(u'^(\s|\t)*~*(\s|\t)*\d+(y|Y|j|J|a|A|\s|\t)+\d+(\s|\t)*(m|M)+(\s|\t)*$', str_interval, flags = regex.LOCALE | regex.UNICODE):
+		parts = regex.findall(u'\d+', str_interval, flags = regex.LOCALE | regex.UNICODE)
 		years, months = divmod(int(parts[1]), 12)
 		years += int(parts[0])
 		return pydt.timedelta(days = ((years * days_per_year) + (months * days_per_month)))
@@ -336,6 +353,32 @@ def str2interval(str_interval=None):
 #===========================================================================
 # text related tools
 #---------------------------------------------------------------------------
+_kB = 1024
+_MB = 1024 * _kB
+_GB = 1024 * _MB
+_TB = 1024 * _GB
+_PB = 1024 * _TB
+#---------------------------------------------------------------------------
+def size2str(size=0, template='%s'):
+	if size == 1:
+		return template % _('1 Byte')
+	if size < 10 * _kB:
+		return template % _('%s Bytes') % size
+	if size < _MB:
+		return template % u'%.1f kB' % (float(size) / _kB)
+	if size < _GB:
+		return template % u'%.1f MB' % (float(size) / _MB)
+	if size < _TB:
+		return template % u'%.1f GB' % (float(size) / _GB)
+	if size < _PB:
+		return template % u'%.1f TB' % (float(size) / _TB)
+	return template % u'%.1f PB' % (float(size) / _PB)
+#---------------------------------------------------------------------------
+def bool2str(bool=None, true_str='True', false_str='False'):
+	if bool is True:
+		return true_str
+	return false_str
+#---------------------------------------------------------------------------
 def none_if(value=None, none_equivalent=None):
 	"""Modelled after the SQL NULLIF function."""
 	if value == none_equivalent:
@@ -361,6 +404,10 @@ def coalesce(initial=None, instead=None, template_initial=None, template_instead
 	@type template_initial: string or None
 	@param template_instead: if <instead> is returned replace the value into this template, must contain one <%s> 
 	@type template_instead: string or None
+
+	Ideas:
+		- list of None-equivalents
+		- list of insteads: initial, [instead, template], [instead, template], [instead, template], template_initial, ...
 	"""
 	if initial is None:
 		if template_instead is None:
@@ -400,13 +447,13 @@ def capitalize(text=None, mode=CAPS_NAMES):
 		return text[0].upper() + text[1:].lower()
 
 	if mode == CAPS_WORDS:
-		return regex.sub(r'(\w)(\w+)', lambda x: x.group(1).upper() + x.group(2).lower(), text)
+		return regex.sub(ur'(\w)(\w+)', lambda x: x.group(1).upper() + x.group(2).lower(), text)
 
 	if mode == CAPS_NAMES:
 		#return regex.sub(r'\w+', __cap_name, text)
 		return capitalize(text=text, mode=CAPS_FIRST)		# until fixed
 
-	print "ERROR: invalid capitalize() mode: [%s], leaving input as is", mode
+	print "ERROR: invalid capitalization mode: [%s], leaving input as is" % mode
 	return text
 #---------------------------------------------------------------------------
 def wrap(text, width):
@@ -437,13 +484,6 @@ if __name__ == '__main__':
 
 	_log.SetAllLogLevels(gmLog.lData)
 
-	#-----------------------------------------------------------------------
-	def test_open_uri_in_ooo():
-		try:
-			open_uri_in_ooo(filename=sys.argv[1])
-		except:
-			_log.LogException('cannot open [%s] in OOo' % sys.argv[1])
-			raise
 	#-----------------------------------------------------------------------
 	def test_str2interval():
 		print "testing str2interval()"
@@ -470,7 +510,8 @@ if __name__ == '__main__':
 		print 'testing coalesce()'
 		print "------------------"
 		tests = [
-			[None, 'something other than <None>', None, None, 'something other than <None>']
+			[None, 'something other than <None>', None, None, 'something other than <None>'],
+			['Captain', 'Mr.', '%s.'[:4], 'Mr.', 'Capt.']
 		]
 		passed = True
 		for test in tests:
@@ -494,9 +535,10 @@ if __name__ == '__main__':
 		return passed
 	#-----------------------------------------------------------------------
 	def test_capitalize():
-		print 'testing capitalize()'
-		print '--------------------'
+		print 'testing capitalize() ...'
+		success = True
 		pairs = [
+			# [original, expected result, CAPS mode]
 			[u'Boot', u'Boot', CAPS_FIRST_ONLY],
 			[u'boot', u'Boot', CAPS_FIRST_ONLY],
 			[u'booT', u'Boot', CAPS_FIRST_ONLY],
@@ -505,14 +547,24 @@ if __name__ == '__main__':
 			[u'boots-sChau', u'Boots-Schau', CAPS_WORDS],
 			[u'boot camp', u'Boot Camp', CAPS_WORDS],
 			[u'fahrner-Kampe', u'Fahrner-Kampe', CAPS_NAMES],
-			[u'häkkönen', u'Häkkönen', CAPS_NAMES]
+			[u'häkkönen', u'Häkkönen', CAPS_NAMES],
+			[u'McBurney', u'McBurney', CAPS_NAMES],
+			[u'mcBurney', u'McBurney', CAPS_NAMES],
+			[u'blumberg', u'Blumberg', CAPS_NAMES],
+			[u'roVsing', u'RoVsing', CAPS_NAMES],
+			[u'Özdemir', u'Özdemir', CAPS_NAMES],
+			[u'özdemir', u'Özdemir', CAPS_NAMES],
 		]
 		for pair in pairs:
 			result = capitalize(pair[0], pair[2])
 			if result != pair[1]:
+				success = False
 				print 'ERROR (caps mode %s): "%s" -> "%s", expected "%s"' % (pair[2], pair[0], result, pair[1])
 
-		return True
+		if success:
+			print "... SUCCESS"
+
+		return success
 	#-----------------------------------------------------------------------
 	def test_import_module():
 		print "testing import_module_from_directory()"
@@ -547,10 +599,10 @@ This is a test mail from the gmTools.py module.
 			debug = True
 		)
 	#-----------------------------------------------------------------------
-	def test_cPaths():
-		print "testing cPaths()"
-		print "----------------"
-		paths = cPaths(wx=None, app_name='gnumed')
+	def test_gmPaths():
+		print "testing gmPaths()"
+		print "-----------------"
+		paths = gmPaths(wx=None, app_name='gnumed')
 		print "user     config dir:", paths.user_config_dir
 		print "system   config dir:", paths.system_config_dir
 		print "local      base dir:", paths.local_base_dir
@@ -578,20 +630,92 @@ This is a test mail from the gmTools.py module.
 
 		return True
 	#-----------------------------------------------------------------------
-	print __doc__
+	def test_bool2str():
+		tests = [
+			[True, 'Yes', 'Yes', 'Yes'],
+			[False, 'OK', 'not OK', 'not OK']
+		]
+		for test in tests:
+			if bool2str(test[0], test[1], test[2]) != test[3]:
+				print 'ERROR: bool2str(%s, %s, %s) returned [%s], expected [%s]' % (test[0], test[1], test[2], bool2str(test[0], test[1], test[2]), test[3])
 
-	#test_str2interval()
-	#test_coalesce()
-	#test_capitalize()
-	#test_open_uri_in_ooo()
-	#test_import_module()
-	#test_mkdir()
-	#test_send_mail()
-	test_cPaths()
-	#test_none_if()
+		return True
+
+	#-----------------------------------------------------------------------
+	def test_get_unique_filename():
+		print get_unique_filename()
+		print get_unique_filename(prefix='test-')
+		print get_unique_filename(suffix='tst')
+		print get_unique_filename(prefix='test-', suffix='tst')
+		print get_unique_filename(dir='/home/ncq/Archiv/')
+	#-----------------------------------------------------------------------
+	def test_size2str():
+		print "testing size2str()"
+		print "------------------"
+		tests = [0, 1, 1000, 10000, 100000, 1000000, 10000000, 100000000, 1000000000, 10000000000, 100000000000, 1000000000000, 10000000000000]
+		for test in tests:
+			print size2str(test)
+	#-----------------------------------------------------------------------
+	if len(sys.argv) > 1 and sys.argv[1] == 'test':
+		#test_str2interval()
+		#test_coalesce()
+		#test_capitalize()
+		#test_import_module()
+		#test_mkdir()
+		#test_send_mail()
+		#test_gmPaths()
+		#test_none_if()
+		#test_bool2str()
+		#test_get_unique_filename()
+		test_size2str()
 
 #===========================================================================
 # $Log: gmTools.py,v $
+# Revision 1.43  2007/11/28 13:59:23  ncq
+# - test improved
+#
+# Revision 1.42  2007/11/21 13:28:35  ncq
+# - enhance send_mail() with subject and encoding
+# - handle body formatting
+#
+# Revision 1.41  2007/10/23 21:23:30  ncq
+# - cleanup
+#
+# Revision 1.40  2007/10/09 10:29:02  ncq
+# - clean up import_module_from_directory()
+#
+# Revision 1.39  2007/10/08 12:48:17  ncq
+# - normalize / and \ in import_module_from_directory() so it works on Windows
+#
+# Revision 1.38  2007/08/29 14:33:56  ncq
+# - better document get_unique_filename()
+#
+# Revision 1.37  2007/08/28 21:47:19  ncq
+# - log user home dir
+#
+# Revision 1.36  2007/08/15 09:18:56  ncq
+# - size2str() and test
+#
+# Revision 1.35  2007/08/07 21:41:02  ncq
+# - cPaths -> gmPaths
+#
+# Revision 1.34  2007/07/13 09:47:38  ncq
+# - fix and test suite for get_unique_filename()
+#
+# Revision 1.33  2007/07/11 21:06:51  ncq
+# - improved docs
+# - get_unique_filename()
+#
+# Revision 1.32  2007/07/10 20:45:42  ncq
+# - add unicode CSV reader
+# - factor out OOo related code
+#
+# Revision 1.31  2007/06/19 12:43:17  ncq
+# - add bool2str() and test
+#
+# Revision 1.30  2007/06/10 09:56:03  ncq
+# - u''ificiation and flags in regex calls
+#
 # Revision 1.29  2007/05/17 15:12:59  ncq
 # - even more careful about pathes
 #
