@@ -3,15 +3,17 @@
 # About GNUmed
 #====================================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmAbout.py,v $
-# $Id: gmAbout.py,v 1.25 2006/10/23 15:48:07 ncq Exp $
-__version__ = "$Revision: 1.25 $"
+# $Id: gmAbout.py,v 1.29 2007/09/20 19:34:04 ncq Exp $
+__version__ = "$Revision: 1.29 $"
 __author__ = "M.Bonert"
 __license__ = "GPL"
 
-import zlib, cPickle
+import zlib, cPickle, sys
+
 
 import wx
 
+
 try:
 	_('dummy-no-need-to-translate')
 except NameError:
@@ -174,30 +176,50 @@ class cContributorsDlg(wx.Dialog):
 'address it is sorted under the first character of\n'
 'the user name.\n'
 '%s'
-) % """
+) % u"""
 == F ===========================================
 
 Joachim Fischer
  GP Fischer + Lintz
- Fachrzte Allgemeinmedizin
+ Fachärzte Allgemeinmedizin
  Wolfschlugen
 
- - Karteieintragsarten passend fr Deutschland
+ - Karteieintragsarten passend für Deutschland
+
+== L ===========================================
+
+Steffi Leibner, Leipzig
+
+ - Testen, Fehlerberichte
+ - Dokumentenvorlage
+
+== N ===========================================
+
+Clemens Nietfeld, Oldenburg
+
+ - Information zur Anbindung von DocConcept
 
 == P ===========================================
 
-Martin Preuss
+Martin Preuss, Hamburg
 
  - Chipkartenansteuerung
 
+== R ===========================================
+
+Thomas Reus, Düsseldorf
+
+ - Testen, Fehlerberichte
+ - Dokumentenvorlage
+
 == T ===========================================
 
-Andreas Tille
+Andreas Tille, Wernigerode
 
  - Debian packages
  - encouragement, wisdom
 
-""".decode('latin1')
+"""
 	#----------------------------------------------
 	def __init__(self, *args, **kwargs):
 		wx.Dialog.__init__(self, *args, **kwargs)
@@ -228,12 +250,24 @@ if __name__ == '__main__':
 			frame.Show(1)
 			return 1
 	#---------------------
-	_ = lambda x:x
-	app = TestApp ()
-	app.MainLoop ()
+	if len(sys.argv) > 1 and sys.argv[1] == 'test':
+		app = TestApp()
+		app.MainLoop()
 
 #------------------------------------------------------------
 # $Log: gmAbout.py,v $
+# Revision 1.29  2007/09/20 19:34:04  ncq
+# - cleanup
+#
+# Revision 1.28  2007/09/10 12:35:08  ncq
+# - make accessible to epydoc
+#
+# Revision 1.27  2007/08/29 14:37:00  ncq
+# - add Clemens Nietfeld
+#
+# Revision 1.26  2007/08/20 14:22:24  ncq
+# - add more helpful people
+#
 # Revision 1.25  2006/10/23 15:48:07  ncq
 # - fix unicode/latin1 string issue
 #
