@@ -3,7 +3,7 @@
 """
 ############################################################################
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmAllergyWidgets.py,v $
-__version__ = "$Revision: 1.28 $"
+__version__ = "$Revision: 1.28.2.1 $"
 __author__  = "R.Terry <rterry@gnumed.net>, H.Herb <hherb@gnumed.net>, K.Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = 'GPL (details at http://www.gnu.org)'
 
@@ -213,7 +213,7 @@ class cAllergyManagerDlg(wxgAllergyManagerDlg.wxgAllergyManagerDlg):
 		wxgAllergyManagerDlg.wxgAllergyManagerDlg.__init__(self, *args, **kwargs)
 
 		self.__set_columns()
-		self._PNL_edit_area._ChBOX_definite.MoveAfterInTabOrder(self._BTN_save)
+		#self._PNL_edit_area._ChBOX_definite.MoveAfterInTabOrder(self._BTN_save)
 		self.__refresh_ui()
 	#--------------------------------------------------------
 	# internal helpers
@@ -467,6 +467,9 @@ if __name__ == "__main__":
 #		app.MainLoop()
 #======================================================================
 # $Log: gmAllergyWidgets.py,v $
+# Revision 1.28.2.1  2008/01/16 15:16:16  ncq
+# - MacOSX doesn't like Move*InTabOrder across sizers
+#
 # Revision 1.28  2007/10/25 12:19:53  ncq
 # - no more useless allergy update
 #
