@@ -5,8 +5,8 @@ functions for authenticating users.
 """
 #================================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmAuthWidgets.py,v $
-# $Id: gmAuthWidgets.py,v 1.2 2007/12/04 16:14:52 ncq Exp $
-__version__ = "$Revision: 1.2 $"
+# $Id: gmAuthWidgets.py,v 1.2.2.3 2008/07/10 09:03:50 ncq Exp $
+__version__ = "$Revision: 1.2.2.3 $"
 __author__ = "karsten.hilbert@gmx.net, H.Herb, H.Berger, R.Terry"
 __license__ = "GPL (details at http://www.gnu.org)"
 
@@ -239,15 +239,14 @@ class cLoginPanel(wx.Panel):
 		wx.Panel.__init__(self, parent, id, pos, size, style)
 		self.parent = parent
 
-		self.user_preferences_file = None
 		paths = gmTools.gmPaths(app_name = 'gnumed', wx=wx)
+		fnames = []
 		if gmCLI.has_arg('--conf-file'):
-			fnames = [gmCLI.arg['--conf-file']]
-		else:
-			fnames = [
-				os.path.join(paths.user_config_dir, 'gnumed.conf'),
-				os.path.join(paths.working_dir, 'gnumed.conf')
-			]
+			fnames.append(gmCLI.arg['--conf-file'])
+		fnames.append(os.path.join(paths.user_config_dir, 'gnumed.conf'))
+		fnames.append(os.path.join(paths.local_base_dir, 'gnumed.conf'))
+		fnames.append(os.path.join(paths.working_dir, 'gnumed.conf'))
+		self.user_preferences_file = None
 		for fname in fnames:
 			try:
 				open(fname, 'r+b')
@@ -548,12 +547,11 @@ class cLoginPanel(wx.Panel):
 			)
 		)
 
-		self._CBOX_profile.SetValue (
-			gmTools.coalesce (
-				prefs.get('preferences', 'profile'),
-				self.__backend_profiles[self.__backend_profiles.keys()[0]].name
-			)
-		)
+		prefs_profile = prefs.get('preferences', 'profile')
+		try:
+			self._CBOX_profile.SetValue(self.__backend_profiles[prefs_profile].name)
+		except KeyError:
+			self._CBOX_profile.SetValue(self.__backend_profiles[self.__backend_profiles.keys()[0]].name)
 
 		self._CHBOX_debug.SetValue(gmCLI.has_arg('--debug'))
 		self._CHBOX_slave.SetValue(gmCLI.has_arg('--slave'))
@@ -592,7 +590,7 @@ class cLoginPanel(wx.Panel):
 	def OnHelp(self, event):
 		tmp = _cfg.get('workplace', 'help desk')
 		if tmp is None:
-			print _("You need to set the option [workplace] -> <help desk> in the config file !")
+			print "You need to set the option [workplace] -> <help desk> in the config file !"
 			tmp = "http://www.gnumed.org"
 
 		wx.MessageBox(_(
@@ -678,6 +676,15 @@ if __name__ == "__main__":
 
 #================================================================
 # $Log: gmAuthWidgets.py,v $
+# Revision 1.2.2.3  2008/07/10 09:03:50  ncq
+# - be more generous when looking for a writable user prefs file
+#
+# Revision 1.2.2.2  2008/06/25 08:59:06  ncq
+# - don't try printing utf8 to console
+#
+# Revision 1.2.2.1  2008/01/30 11:19:54  ncq
+# - don't fail on faulty profile name in [preferences]
+#
 # Revision 1.2  2007/12/04 16:14:52  ncq
 # - get_dbowner_connection()
 #
