@@ -2,8 +2,8 @@
 """
 #================================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmEMRBrowser.py,v $
-# $Id: gmEMRBrowser.py,v 1.75 2007/05/21 14:48:20 ncq Exp $
-__version__ = "$Revision: 1.75 $"
+# $Id: gmEMRBrowser.py,v 1.81 2007/09/07 10:56:57 ncq Exp $
+__version__ = "$Revision: 1.81 $"
 __author__ = "cfmoro1976@yahoo.es, sjtan@swiftdsl.com.au, Karsten.Hilbert@gmx.net"
 __license__ = "GPL"
 
@@ -17,7 +17,7 @@ import wx
 from Gnumed.pycommon import gmLog, gmI18N, gmDispatcher, gmSignals, gmExceptions, gmTools
 from Gnumed.exporters import gmPatientExporter
 from Gnumed.business import gmEMRStructItems, gmPerson, gmSOAPimporter
-from Gnumed.wxpython import gmGuiHelpers, gmEMRStructWidgets, gmSOAPWidgets, gmAllergyWidgets
+from Gnumed.wxpython import gmGuiHelpers, gmEMRStructWidgets, gmSOAPWidgets, gmAllergyWidgets, gmNarrativeWidgets
 from Gnumed.wxGladeWidgets import wxgScrolledEMRTreePnl, wxgSplittedEMRTreeBrowserPnl
 
 _log = gmLog.gmDefLog
@@ -36,7 +36,7 @@ def export_emr_to_ascii(parent=None):
 
 	pat = gmPerson.gmCurrentPatient()
 	if not pat.is_connected():
-		gmDispatcher.send(signal=gmSignals.statustext(), msg=_('Cannot export EMR. No active patient.'))
+		gmDispatcher.send(signal='statustext', msg=_('Cannot export EMR. No active patient.'))
 		return False
 
 	# get file name
@@ -70,7 +70,7 @@ def export_emr_to_ascii(parent=None):
 	exporter.dump_med_docs()
 	output_file.close()
 
-	gmDispatcher.send(gmSignals.statustext(), msg = _('EMR successfully exported to file: %s') % fname, beep = False)
+	gmDispatcher.send('statustext', msg = _('EMR successfully exported to file: %s') % fname, beep = False)
 	return fname
 #============================================================
 class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
@@ -100,7 +100,7 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 	#--------------------------------------------------------
 	def refresh(self):
 		if not self.__pat.is_connected():
-			gmDispatcher.send(signal=gmSignals.statustext(), msg=_('Cannot load clinical narrative. No active patient.'),)
+			gmDispatcher.send(signal='statustext', msg=_('Cannot load clinical narrative. No active patient.'),)
 			return False
 
 		if not self.__populate_tree():
@@ -140,6 +140,8 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 		# and uncollapse
 		self.Expand(root_item)
 
+		self.SortChildren(root_item)
+
 		# display patient summary info
 		label = _('Summary')
 		underline = '=' * len(label)
@@ -156,36 +158,41 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 	def __make_popup_menus(self):
 
 		# - episodes
-		self.__epi_context_popup = wx.Menu()
+		self.__epi_context_popup = wx.Menu(title = _('Episode Menu'))
 
 		menu_id = wx.NewId()
-		self.__epi_context_popup.AppendItem(wx.MenuItem(self.__epi_context_popup, menu_id, _('Edit episode details')))
+		self.__epi_context_popup.AppendItem(wx.MenuItem(self.__epi_context_popup, menu_id, _('Edit details')))
 		wx.EVT_MENU(self.__epi_context_popup, menu_id, self.__edit_episode)
 
 		menu_id = wx.NewId()
-		self.__epi_context_popup.AppendItem(wx.MenuItem(self.__epi_context_popup, menu_id, _('Delete episode')))
+		self.__epi_context_popup.AppendItem(wx.MenuItem(self.__epi_context_popup, menu_id, _('Delete')))
 		wx.EVT_MENU(self.__epi_context_popup, menu_id, self.__delete_episode)
 		# attach all encounters to another episode
 
 		# - encounters
-		self.__enc_context_popup = wx.Menu()
+		self.__enc_context_popup = wx.Menu(title = _('Encounter Menu'))
 		# - move data
 		menu_id = wx.NewId()
-		self.__enc_context_popup.AppendItem(wx.MenuItem(self.__enc_context_popup, menu_id, _('move encounter data to another episode')))
+		self.__enc_context_popup.AppendItem(wx.MenuItem(self.__enc_context_popup, menu_id, _('Move data to another episode')))
 		wx.EVT_MENU(self.__enc_context_popup, menu_id, self.__relink_encounter_data2episode)
 		# - edit encounter details
 		menu_id = wx.NewId()
-		self.__enc_context_popup.AppendItem(wx.MenuItem(self.__enc_context_popup, menu_id, _('edit consultation details')))
+		self.__enc_context_popup.AppendItem(wx.MenuItem(self.__enc_context_popup, menu_id, _('Edit details')))
 		wx.EVT_MENU(self.__enc_context_popup, menu_id, self.__edit_consultation_details)
 
 		# - health issues
-		self.__issue_context_popup = wx.Menu()
+		self.__issue_context_popup = wx.Menu(title = _('Health Issue Menu'))
+		# edit
 		menu_id = wx.NewId()
-		self.__issue_context_popup.AppendItem(wx.MenuItem(self.__issue_context_popup, menu_id, _('edit health issue')))
+		self.__issue_context_popup.AppendItem(wx.MenuItem(self.__issue_context_popup, menu_id, _('Edit details')))
 		wx.EVT_MENU(self.__issue_context_popup, menu_id, self.__edit_issue)
-		
+		# delete
+		menu_id = wx.NewId()
+		self.__issue_context_popup.AppendItem(wx.MenuItem(self.__issue_context_popup, menu_id, _('Delete')))
+		wx.EVT_MENU(self.__issue_context_popup, menu_id, self.__delete_issue)
+
 		# - root node
-		self.__root_context_popup = wx.Menu()
+		self.__root_context_popup = wx.Menu(title = _('EMR Menu'))
 		# add health issue
 		menu_id = wx.NewId()
 		self.__root_context_popup.AppendItem(wx.MenuItem(self.__root_context_popup, menu_id, _('create health issue')))
@@ -230,7 +237,7 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 		try:
 			gmEMRStructItems.delete_episode(episode = self.__curr_node_data)
 		except gmExceptions.DatabaseObjectInUseError:
-			gmDispatcher.send(signal = gmSignals.statustext(), msg = _('Cannot delete episode. There is still clinical data recorded for it.'))
+			gmDispatcher.send(signal = 'statustext', msg = _('Cannot delete episode. There is still clinical data recorded for it.'))
 			return
 
 		self.__populate_tree()
@@ -250,7 +257,7 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 		node_parent = self.GetItemParent(self.__curr_node)
 		owning_episode = self.GetPyData(node_parent)
 
-		episode_selector = gmEMRStructWidgets.cMoveNarrativeDlg (
+		episode_selector = gmNarrativeWidgets.cMoveNarrativeDlg (
 			self,
 			-1,
 			episode = owning_episode,
@@ -263,38 +270,6 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 		if result == wx.ID_YES:
 			self.__populate_tree()
 	#--------------------------------------------------------
-#	def __find_node(self, root, data_object):
-#		nodes = []
-#		id , cookie = self.GetFirstChild(root)
-
-		#print "DEBUG id , cookie", id, cookie
-		#print "DEBUG id dict is ", id.__dict__.keys()
-#		while id.IsOk():
-#			nodes.append(id)
-#			id, cookie = self.GetNextChild( root, cookie)
-
-#		l = [x for x in nodes if self.GetPyData(x) == data_object]
-#		if l == []:
-#			print "DEBUG looking further in ", nodes
-#			if nodes == []:
-#				return None
-#			else:
-#				for x in nodes:
-#					val = self.__find_node(x, data_object)
-#					if val:
-#						return val
-#		else:
-#			return l[0]
-	#--------------------------------------------------------
-#	def __move_node(self, node, target_node):
-#		new_node = self.AppendItem(target_node, self.GetItemText(node))
-#		self.SetPyData(new_node, self.GetPyData(node))
-#		id, cookie = self.GetFirstChild(node)
-#		while id.IsOk():
-#			self.__move_node(id, new_node)
-#			id, cookie = self.GetNextChild(node)
-#		self.Delete(node)
-	#--------------------------------------------------------
 	# health issues
 	def __handle_issue_context(self, pos=wx.DefaultPosition):
 #		self.__issue_context_popup.SetTitle(_('Episode %s') % episode['description'])
@@ -306,6 +281,33 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 			self.__populate_tree()
 		return
 	#--------------------------------------------------------
+	def __delete_issue(self, event):
+		dlg = gmGuiHelpers.c2ButtonQuestionDlg (
+			parent = self,
+			id = -1,
+			caption = _('Deleting health issue'),
+			button_defs = [
+				{'label': _('Yes, delete'), 'tooltip': _('Delete the health issue if possible (it must be completely empty).')},
+				{'label': _('No, cancel'), 'tooltip': _('Cancel and do NOT delete the health issue.')}
+			],
+			question = _(
+				'Are you sure you want to delete this health issue ?\n'
+				'\n'
+				' "%s"\n'
+			) % self.__curr_node_data['description']
+		)
+		result = dlg.ShowModal()
+		if result != wx.ID_YES:
+			return
+
+		try:
+			gmEMRStructItems.delete_health_issue(health_issue = self.__curr_node_data)
+		except gmExceptions.DatabaseObjectInUseError:
+			gmDispatcher.send(signal = 'statustext', msg = _('Cannot delete health issue. There is still clinical data recorded for it.'))
+			return
+
+		self.__populate_tree()
+	#--------------------------------------------------------
 	# root
 	def __handle_root_context(self, pos=wx.DefaultPosition):
 		self.PopupMenu(self.__root_context_popup, pos)
@@ -399,6 +401,13 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 				return -1
 			return 1
 
+		if isinstance(item1, gmEMRStructItems.cHealthIssue):
+			if item1['description'].lower() == item2['description'].lower():
+				return 0
+			if item1['description'].lower() > item2['description'].lower():
+				return 1
+			return -1
+
 		return 0
 #================================================================
 class cScrolledEMRTreePnl(wxgScrolledEMRTreePnl.wxgScrolledEMRTreePnl):
@@ -549,6 +558,25 @@ if __name__ == '__main__':
 
 #================================================================
 # $Log: gmEMRBrowser.py,v $
+# Revision 1.81  2007/09/07 10:56:57  ncq
+# - cleanup
+#
+# Revision 1.80  2007/08/29 22:09:10  ncq
+# - narrative widgets factored out
+#
+# Revision 1.79  2007/08/15 14:57:52  ncq
+# - pretty up tree popup menus
+# - add deletion of health issues
+#
+# Revision 1.78  2007/08/12 00:09:07  ncq
+# - no more gmSignals.py
+#
+# Revision 1.77  2007/06/18 20:31:10  ncq
+# - case insensitively sort health issues
+#
+# Revision 1.76  2007/06/10 09:56:54  ncq
+# - actually sort tree items, add sorting for health issues
+#
 # Revision 1.75  2007/05/21 14:48:20  ncq
 # - cleanup
 # - use pat['dirname'], use export/EMR/
