@@ -5,8 +5,8 @@
 #embryonic gmGP_PatientPicture.py replacement
 #=====================================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmPatPicWidgets.py,v $
-# $Id: gmPatPicWidgets.py,v 1.24 2007/05/08 11:16:32 ncq Exp $
-__version__ = "$Revision: 1.24 $"
+# $Id: gmPatPicWidgets.py,v 1.28 2007/09/10 12:37:37 ncq Exp $
+__version__ = "$Revision: 1.28 $"
 __author__  = "R.Terry <rterry@gnumed.net>,\
 			   I.Haywood <i.haywood@ugrad.unimelb.edu.au>,\
 			   K.Hilbert <Karsten.Hilbert@gmx.net>"
@@ -41,7 +41,7 @@ class cPatientPicture(wx.StaticBitmap):
 	def __init__(self, parent, id, width=50, height=54):
 
 		# find assets
-		paths = gmTools.cPaths(app_name  = 'gnumed', wx = wx)
+		paths = gmTools.gmPaths(app_name  = 'gnumed', wx = wx)
 		self.__fallback_pic_name = os.path.join(paths.system_app_data_dir, 'bitmaps', 'empty-face-in-bust.png')
 
 		# load initial dummy bitmap
@@ -87,7 +87,7 @@ class cPatientPicture(wx.StaticBitmap):
 	#-----------------------------------------------------------------
 	def _on_RightClick_photo(self, event):
 		if not self.__pat.is_connected():
-			gmDispatcher.send(signal=gmSignals.statustext(), msg=_('No active patient.'))
+			gmDispatcher.send(signal='statustext', msg=_('No active patient.'))
 			return False
 		self.PopupMenu(self.__photo_menu, event.GetPosition())
 	#-----------------------------------------------------------------
@@ -113,7 +113,7 @@ class cPatientPicture(wx.StaticBitmap):
 
 		fnames = gmScanBackend.acquire_pages_into_files (
 			delay = 5,
-			tmpdir = os.path.expanduser(os.path.join('~', 'gnumed', 'tmp')),
+			tmpdir = os.path.expanduser(os.path.join('~', '.gnumed', 'tmp')),
 			calling_window = self
 		)
 		if fnames is False:
@@ -157,7 +157,7 @@ class cPatientPicture(wx.StaticBitmap):
 
 		if photo is None:
 			fname = None
-			gmDispatcher.send(signal=gmSignals.statustext(), msg=_('Cannot get most recent patient photo from database.'))
+#			gmDispatcher.send(signal='statustext', msg=_('Cannot get most recent patient photo from database.'))
 		else:
 			fname = photo.export_to_file()
 
@@ -172,7 +172,7 @@ class cPatientPicture(wx.StaticBitmap):
 			bmp_data = wx.BitmapFromImage(img_data)
 		except:
 			_log.LogException('cannot set patient picture from [%s]' % fname)
-			gmDispatcher.send(signal=gmSignals.statustext(), msg=_('Cannot set patient picture from [%s].') % fname)
+			gmDispatcher.send(signal='statustext', msg=_('Cannot set patient picture from [%s].') % fname)
 			return False
 		del img_data
 		self.SetBitmap(bmp_data)
@@ -191,6 +191,20 @@ if __name__ == "__main__":
 	app.MainLoop()
 #====================================================
 # $Log: gmPatPicWidgets.py,v $
+# Revision 1.28  2007/09/10 12:37:37  ncq
+# - don't send signal on not finding patient pic
+#   a) it's quite obvious
+#   b) it might obscure more important messages
+#
+# Revision 1.27  2007/08/12 00:12:41  ncq
+# - no more gmSignals.py
+#
+# Revision 1.26  2007/08/07 21:42:40  ncq
+# - cPaths -> gmPaths
+#
+# Revision 1.25  2007/07/22 09:27:48  ncq
+# - tmp/ now in .gnumed/
+#
 # Revision 1.24  2007/05/08 11:16:32  ncq
 # - need to import gmTools
 #
