@@ -8,8 +8,8 @@ This is based on seminal work by Ian Haywood <ihaywood@gnu.org>
 """
 ############################################################################
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmPhraseWheel.py,v $
-# $Id: gmPhraseWheel.py,v 1.105 2007/05/14 14:43:11 ncq Exp $
-__version__ = "$Revision: 1.105 $"
+# $Id: gmPhraseWheel.py,v 1.110 2007/10/29 11:30:21 ncq Exp $
+__version__ = "$Revision: 1.110 $"
 __author__  = "K.Hilbert <Karsten.Hilbert@gmx.net>, I.Haywood, S.J.Tan <sjtan@bigpond.com>"
 __license__ = "GPL"
 
@@ -58,7 +58,69 @@ class cPhraseWheelListCtrl(wx.ListCtrl, listmixins.ListCtrlAutoWidthMixin):
 	def get_selected_item_label(self):
 		return self.__data[self.GetFirstSelected()]['label']
 #============================================================
-# FIXME: cols in pick list, snap_to_basename/first match on tab+set selection, learn() -> PWL
+# FIXME: cols in pick list
+# FIXME: snap_to_basename+set selection
+# FIXME: learn() -> PWL
+# FIXME: up-arrow: show recent (in-memory) history
+#----------------------------------------------------------
+# ideas
+#----------------------------------------------------------
+#- display possible completion but highlighted for deletion
+#(- cycle through possible completions)
+#- pre-fill selection with SELECT ... LIMIT 25
+#- async threads for match retrieval instead of timer
+#  - on truncated results return item "..." -> selection forcefully retrieves all matches
+
+#- generators/yield()
+#- OnChar() - process a char event
+
+# split input into words and match components against known phrases
+
+# make special list window:
+# - deletion of items
+# - highlight matched parts
+# - faster scrolling
+# - wxEditableListBox ?
+
+# - if non-learning (i.e. fast select only): autocomplete with match
+#   and move cursor to end of match
+#-----------------------------------------------------------------------------------------------
+# darn ! this clever hack won't work since we may have crossed a search location threshold
+#----
+#	#self.__prevFragment = "XXXXXXXXXXXXXXXXXX-very-unlikely--------------XXXXXXXXXXXXXXX"
+#	#self.__prevMatches = []		# a list of tuples (ID, listbox name, weight)
+#
+#	# is the current fragment just a longer version of the previous fragment ?
+#	if string.find(aFragment, self.__prevFragment) == 0:
+#	    # we then need to search in the previous matches only
+#	    for prevMatch in self.__prevMatches:
+#		if string.find(prevMatch[1], aFragment) == 0:
+#		    matches.append(prevMatch)
+#	    # remember current matches
+#	    self.__prefMatches = matches
+#	    # no matches found
+#	    if len(matches) == 0:
+#		return [(1,_('*no matching items found*'),1)]
+#	    else:
+#		return matches
+#----
+#TODO:
+# - see spincontrol for list box handling
+# stop list (list of negatives): "an" -> "animal" but not "and"
+#-----
+#> > remember, you should be searching on  either weighted data, or in some
+#> > situations a start string search on indexed data
+#>
+#> Can you be a bit more specific on this ?
+
+#seaching ones own previous text entered  would usually be instring but
+#weighted (ie the phrases you use the most auto filter to the top)
+
+#Searching a drug database for a   drug brand name is usually more
+#functional if it does a start string search, not an instring search which is
+#much slower and usually unecesary.  There are many other examples but trust
+#me one needs both
+#-----
 class cPhraseWheel(wx.TextCtrl):
 	"""Widget for smart guessing of user fields, after Richard Terry's interface.
 
@@ -104,11 +166,10 @@ class cPhraseWheel(wx.TextCtrl):
 		self.matcher = None
 		self.selection_only = False
 		self.selection_only_error_msg = _('You must select a value from the picklist or type an exact match.')
-#		self.snap_to_first_match = (False or self.selection_only)
 		self.capitalisation_mode = gmTools.CAPS_NONE
 		self.accepted_chars = None
 		self.final_regex = '.*'
-		self.final_regex_error_msg = _('The content is invalid. It must match the pattern: [%s]') % self.__final_regex.pattern
+		self.final_regex_error_msg = _('The content is invalid. It must match the pattern: [%s]')
 		self.phrase_separators = '[;/|]+'
 		self.navigate_after_selection = False
 		self.speller = None
@@ -175,9 +236,6 @@ class cPhraseWheel(wx.TextCtrl):
 	#--------------------------------------------------------
 	# external API
 	#--------------------------------------------------------
-#	def set_snap_to_first_match(self, state = False):
-#		self.snap_to_first_match = (state or self.selection_only)
-	#--------------------------------------------------------
 	def add_callback_on_selection(self, callback=None):
 		"""
 		Add a callback for invocation when a picklist item is selected.
@@ -255,7 +313,7 @@ class cPhraseWheel(wx.TextCtrl):
 		self.SetBackgroundColour(wx.SystemSettings_GetColour(wx.SYS_COLOUR_WINDOW))
 		return True
 	#---------------------------------------------------------
-	def GetData (self):
+	def GetData(self):
 		"""
 		Retrieve the data associated with the displayed string.
 		"""
@@ -676,15 +734,6 @@ class cPhraseWheel(wx.TextCtrl):
 		for callback in self._on_set_focus_callbacks:
 			callback()
 
-#		if self.snap_to_first_match:
-#			if self.GetValue().strip() == u'':
-#				# programmers better make sure the turnaround time is limited
-#				self.__update_matches_in_picklist(val='*')
-#				if len(self.__current_matches) > 0:
-#					wx.TextCtrl.SetValue(self, self.__current_matches[0]['label'])
-#					self.data = self.__current_matches[0]['data']
-#					self.MarkDirty()
-#
 		self.__timer.Start(oneShot = True, milliseconds = self.picklist_delay)
 
 		return True
@@ -721,12 +770,12 @@ class cPhraseWheel(wx.TextCtrl):
 		# no exact match found
 		if self.data is None:
 			if self.selection_only:
-				gmDispatcher.send(signal=gmSignals.statustext(), msg=self.selection_only_error_msg)
+				gmDispatcher.send(signal='statustext', msg=self.selection_only_error_msg)
 				self.SetBackgroundColour('pink')
 
 		# check value against final_regex if any given
 		if not self.__final_regex.match(self.GetValue().strip()):
-			gmDispatcher.send(signal=gmSignals.statustext(), msg=self.final_regex_error_msg)
+			gmDispatcher.send(signal='statustext', msg=self.final_regex_error_msg % self.__final_regex.pattern)
 			self.SetBackgroundColour('pink')
 
 		# notify interested parties
@@ -741,7 +790,7 @@ class cPhraseWheel(wx.TextCtrl):
 if __name__ == '__main__':
 	from Gnumed.pycommon import gmI18N
 	gmI18N.activate_locale()
-	gmI18N.install_domain(text_domain='gnumed')
+	gmI18N.install_domain(domain='gnumed')
 
 	from Gnumed.pycommon import gmPG2, gmMatchProvider
 
@@ -860,6 +909,23 @@ if __name__ == '__main__':
 
 #==================================================
 # $Log: gmPhraseWheel.py,v $
+# Revision 1.110  2007/10/29 11:30:21  ncq
+# - rephrase TODOs
+#
+# Revision 1.109  2007/09/02 20:56:30  ncq
+# - cleanup
+#
+# Revision 1.108  2007/08/12 00:12:41  ncq
+# - no more gmSignals.py
+#
+# Revision 1.107  2007/07/10 20:27:27  ncq
+# - install_domain() arg consolidation
+#
+# Revision 1.106  2007/07/03 16:03:04  ncq
+# - cleanup
+# - compile final_regex_error_msg just before using it
+#   since self.final_regex can have changed
+#
 # Revision 1.105  2007/05/14 14:43:11  ncq
 # - allow TAB to select item from picklist if only one match available
 #
@@ -1249,66 +1315,3 @@ if __name__ == '__main__':
 # - cleanup
 #
 #
-#==================================================
-
-#----------------------------------------------------------
-# ideas
-#----------------------------------------------------------
-#- display possible completion but highlighted for deletion
-#(- cycle through possible completions)
-#- pre-fill selection with SELECT ... LIMIT 25
-#- async threads for match retrieval instead of timer
-#  - on truncated results return item "..." -> selection forcefully retrieves all matches
-
-#- generators/yield()
-#- OnChar() - process a char event
-
-# split input into words and match components against known phrases
-
-# make special list window:
-# - deletion of items
-# - highlight matched parts
-# - faster scrolling
-# - wxEditableListBox ?
-
-# - if non-learning (i.e. fast select only): autocomplete with match
-#   and move cursor to end of match
-#-----------------------------------------------------------------------------------------------
-# darn ! this clever hack won't work since we may have crossed a search location threshold
-#----
-#	#self.__prevFragment = "XXXXXXXXXXXXXXXXXX-very-unlikely--------------XXXXXXXXXXXXXXX"
-#	#self.__prevMatches = []		# a list of tuples (ID, listbox name, weight)
-#
-#	# is the current fragment just a longer version of the previous fragment ?
-#	if string.find(aFragment, self.__prevFragment) == 0:
-#	    # we then need to search in the previous matches only
-#	    for prevMatch in self.__prevMatches:
-#		if string.find(prevMatch[1], aFragment) == 0:
-#		    matches.append(prevMatch)
-#	    # remember current matches
-#	    self.__prefMatches = matches
-#	    # no matches found
-#	    if len(matches) == 0:
-#		return [(1,_('*no matching items found*'),1)]
-#	    else:
-#		return matches
-#----
-#TODO:
-# - see spincontrol for list box handling
-# stop list (list of negatives): "an" -> "animal" but not "and"
-
-# maybe store fixed list matches as balanced tree if otherwise to slow
-#-----
-#> > remember, you should be searching on  either weighted data, or in some
-#> > situations a start string search on indexed data
-#>
-#> Can you be a bit more specific on this ?
-
-#seaching ones own previous text entered  would usually be instring but
-#weighted (ie the phrases you use the most auto filter to the top)
-
-#Searching a drug database for a   drug brand name is usually more
-#functional if it does a start string search, not an instring search which is
-#much slower and usually unecesary.  There are many other examples but trust
-#me one needs both
-#-----
