@@ -4,17 +4,21 @@
 """
 #==================================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmPlugin.py,v $
-# $Id: gmPlugin.py,v 1.70 2007/05/08 11:16:32 ncq Exp $
-__version__ = "$Revision: 1.70 $"
+# $Id: gmPlugin.py,v 1.75 2007/11/23 23:35:47 ncq Exp $
+__version__ = "$Revision: 1.75 $"
 __author__ = "H.Herb, I.Haywood, K.Hilbert"
 __license__ = 'GPL (details at http://www.gnu.org)'
 
-import os, sys, re
+import os, sys, re, glob
+
 
 import wx
 
+
+if __name__ == '__main__':
+	sys.path.insert(0, '../../')
 from Gnumed.pycommon import gmExceptions, gmGuiBroker, gmLog, gmCfg, gmDispatcher, gmSignals, gmTools
-from Gnumed.business import gmPerson
+from Gnumed.business import gmPerson, gmSurgery
 
 _log = gmLog.gmDefLog
 _log.Log(gmLog.lInfo, __version__)
@@ -24,14 +28,14 @@ class cLoadProgressBar (wx.ProgressDialog):
 	def __init__(self, nr_plugins):
 		wx.ProgressDialog.__init__(
 			self,
-			title = _("GNUmed: configuring [%s] (%s plugins)") % (gmPerson.gmCurrentProvider().workplace, nr_plugins),
+			title = _("GNUmed: configuring [%s] (%s plugins)") % (gmSurgery.gmCurrentPractice().active_workplace, nr_plugins),
 			message = _("loading list of plugins                               "),
 			maximum = nr_plugins,
 			parent = None,
 			style = wx.PD_ELAPSED_TIME
 			)
 		# set window icon
-		paths = gmTools.cPaths(app_name = u'gnumed', wx = wx)
+		paths = gmTools.gmPaths(app_name = u'gnumed', wx = wx)
 		png_fname = os.path.join(paths.system_app_data_dir, 'bitmaps', 'serpent.png')
 		icon = wx.EmptyIcon()
 		try:
@@ -172,7 +176,9 @@ class cNotebookPlugin:
 
 		This can be used to populate the plugin widget on receiving focus.
 		"""
-		self._widget.repopulate_ui()
+		if hasattr(self._widget, 'repopulate_ui'):
+			self._widget.repopulate_ui()
+		# else apparently it doesn't need it
 		return True
 	#-----------------------------------------------------
 	def _verify_patient_avail(self):
@@ -184,7 +190,7 @@ class cNotebookPlugin:
 		pat = gmPerson.gmCurrentPatient()
 		if not pat.is_connected():
 			# FIXME: people want an optional red backgound here
-			gmDispatcher.send(gmSignals.statustext(), msg = _('Cannot switch to [%s]: no patient selected') % self.name())
+			gmDispatcher.send('statustext', msg = _('Cannot switch to [%s]: no patient selected') % self.name())
 			return None
 		return 1
 	#-----------------------------------------------------
@@ -218,7 +224,7 @@ class cNotebookPlugin:
 		self.register() # register without changing configuration
 	# -----------------------------------------------------
 	def __register_events(self):
-		gmDispatcher.connect(self._on_raise_by_signal, gmSignals.display_widget())
+		gmDispatcher.connect(signal = 'display_widget', receiver = self._on_raise_by_signal)
 #==================================================================
 class cPatientChange_PluginMixin:
 	"""This mixin adds listening to patient change signals."""
@@ -335,67 +341,66 @@ def instantiate_plugin(aPackage='xxxDEFAULTxxx', plugin_name='xxxDEFAULTxxx'):
 
 	return plugin
 #------------------------------------------------------------------
-def GetPluginLoadList(option, plugin_dir = '', defaults = None):
+def get_installed_plugins(plugin_dir=''):
+	"""Looks for installed plugins in the filesystem.
+
+	The first directory in sys.path which contains a wxpython/gui/
+	is considered the one -- because that's where the import will
+	get it from.
+	"""
+	search_path = None
+	for path in sys.path:
+		tmp = os.path.join(path, 'Gnumed', 'wxpython', plugin_dir)
+		if os.path.exists(tmp):
+			search_path = tmp
+			break
+	if search_path is None:
+		_log.Log(gmLog.lErr, 'unable to find any candidate directory matching [$candidate/Gnumed/wxpython/%s/]' % plugin_dir)
+		_log.Log(gmLog.lErr, 'candidates: %s' % str(sys.path))
+		return []
+
+	_log.Log(gmLog.lInfo, "scanning plugin directory [%s]" % search_path)
+
+	files = glob.glob(os.path.join(search_path, 'gm*.py'))
+	plugins = []
+	for file in files:
+		path, fname = os.path.split(file)
+		mod_name, ext = os.path.splitext(fname)
+		plugins.append(mod_name)
+
+	_log.Log(gmLog.lData, "plugins found: %s" % str(plugins))
+
+	return plugins
+#------------------------------------------------------------------
+def GetPluginLoadList(option, plugin_dir = '', defaults = None, workplace=None):
 	"""Get a list of plugins to load.
 
-	1) from database
+	1) from database if option is not None
 	2) from list of defaults
 	3) if 2 is None, from source directory (then stored in database)
 
 	FIXME: look at gmRichardSpace to see how to load plugins
 	FIXME: NOT from files in directories (important for py2exe)
 	"""
-	curr_workplace = gmPerson.gmCurrentProvider().workplace
+	if workplace is None:
+		workplace = gmSurgery.gmCurrentPractice().active_workplace
 
-	dbcfg = gmCfg.cCfgSQL()
-	p_list = dbcfg.get2 (
-		option = option,
-		workplace = curr_workplace,
-		bias = 'workplace',
-		default = defaults
-	)
+	p_list = None
+
+	if option is not None:
+		dbcfg = gmCfg.cCfgSQL()
+		p_list = dbcfg.get2 (
+			option = option,
+			workplace = workplace,
+			bias = 'workplace',
+			default = defaults
+		)
 
 	if p_list is not None:
 		return p_list
 
 	if defaults is None:
-		_log.Log(gmLog.lInfo, "plugin load order not found in DB, scanning directory and storing in DB")
-
-		# parse plugin directory
-		gb = gmGuiBroker.GuiBroker()
-		candidates = []
-		# find candidate plugins directories
-		for path in sys.path:
-			# make sure it's a system path, not a user defined one
-			if path.find(sys.prefix) == -1:
-				continue
-			if path.find('site-packages') == -1:
-				continue
-			candidates.append(path)
-		if len(candidates) == 0:
-			_log.Log(gmLog.lErr, 'no candidate directories to scan for plugins found among the following')
-			_log.Log(gmLog.lErr, str(sys.path))
-			return defaults
-		# among them find (the) one holding plugins
-		search_path = None
-		for candidate in candidates:
-			tmp = os.path.join(candidate, 'Gnumed', 'wxpython', plugin_dir)
-			if os.path.exists(tmp):
-				search_path = tmp
-				break
-		if search_path is None:
-			_log.Log(gmLog.lErr, 'unable to find any candidate directory matching [$candidate/wxpython/%s/]' % plugin_dir)
-			_log.Log(gmLog.lErr, 'candidates: %s' % str(candidates))
-			return defaults
-		# now scan it
-		files = os.listdir(search_path)
-		_log.Log(gmLog.lData, "plugin set: %s" % plugin_dir)
-		_log.Log(gmLog.lInfo, "scanning plugin directory [%s]" % search_path)
-		_log.Log(gmLog.lData, "files found: %s" % str(files))
-		p_list = []
-		for file in files:
-			if (re.compile ('.+\.py$').match(file)) and (file != '__init__.py'):
-				p_list.append(file[:-3])
+		p_list = get_installed_plugins(plugin_dir = plugin_dir)
 		if (len(p_list) == 0):
 			_log.Log(gmLog.lErr, 'cannot find plugins by scanning plugin directory ?!?')
 			return defaults
@@ -406,7 +411,7 @@ def GetPluginLoadList(option, plugin_dir = '', defaults = None):
 	dbcfg.set (
 		option = option,
 		value = p_list,
-		workplace = curr_workplace
+		workplace = workplace
 	)
 
 	_log.Log(gmLog.lData, "plugin load list stored: %s" % str(p_list))
@@ -423,10 +428,31 @@ def UnloadPlugin (set, name):
 # Main
 #------------------------------------------------------------------
 if __name__ == '__main__':
-	print "please write a unit test"
+
+	if len(sys.argv) > 1 and sys.argv[1] == 'test':
+		print get_installed_plugins('gui')
 
 #==================================================================
 # $Log: gmPlugin.py,v $
+# Revision 1.75  2007/11/23 23:35:47  ncq
+# - cleanup
+# - fix get_installed_plugins()
+# - add workplace option to GetPluginLoadList()
+# - rig test suite
+#
+# Revision 1.74  2007/10/29 13:18:35  ncq
+# - only call repopulate_ui on widgets if they have one as some
+#   won't need it as they update ON_PAINT
+#
+# Revision 1.73  2007/10/08 13:07:19  ncq
+# - factor out get_installed_plugins() even though it doesn't work yet
+#
+# Revision 1.72  2007/08/12 00:12:41  ncq
+# - no more gmSignals.py
+#
+# Revision 1.71  2007/08/07 21:42:40  ncq
+# - cPaths -> gmPaths
+#
 # Revision 1.70  2007/05/08 11:16:32  ncq
 # - need to import gmTools
 #
