@@ -2,8 +2,8 @@
 
 #===========================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmTopPanel.py,v $
-# $Id: gmTopPanel.py,v 1.84 2007/05/21 17:13:43 ncq Exp $
-__version__ = "$Revision: 1.84 $"
+# $Id: gmTopPanel.py,v 1.89 2007/12/02 11:00:58 ncq Exp $
+__version__ = "$Revision: 1.89 $"
 __author__  = "R.Terry <rterry@gnumed.net>, I.Haywood <i.haywood@ugrad.unimelb.edu.au>, K.Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL"
 
@@ -250,7 +250,10 @@ class cMainTopPanel(wx.Panel):
 
 		# client internal signals
 		gmDispatcher.connect(signal=gmSignals.post_patient_selection(), receiver=self._on_post_patient_selection)
-		gmDispatcher.connect(signal=gmSignals.allergy_updated(), receiver=self._update_allergies)
+		gmDispatcher.connect(signal = u'allg_mod_db', receiver = self._update_allergies)
+		gmDispatcher.connect(signal = u'allg_state_mod_db', receiver = self._update_allergies)
+		gmDispatcher.connect(signal = u'name_mod_db', receiver = self._on_name_identity_change)
+		gmDispatcher.connect(signal = u'identity_mod_db', receiver = self._on_name_identity_change)
 	#----------------------------------------------
 	def _on_lock(self, evt):
 		print "should be locking client now by obscuring data"
@@ -260,7 +263,7 @@ class cMainTopPanel(wx.Panel):
 	def _on_allergies_dclicked(self, evt):
 		pat = gmPerson.gmCurrentPatient()
 		if not pat.is_connected():
-			gmDispatcher.send(gmSignals.statustext(), msg = _('Cannot activate Allergy Manager. No active patient.'))
+			gmDispatcher.send('statustext', msg = _('Cannot activate Allergy Manager. No active patient.'))
 			return
 		dlg = gmAllergyWidgets.cAllergyManagerDlg(parent=self, id=-1)
 		dlg.ShowModal()
@@ -291,18 +294,25 @@ class cMainTopPanel(wx.Panel):
 #				gmLog.lErr
 #			)
 	#----------------------------------------------
+	def _on_name_identity_change(self):
+		wx.CallAfter(self.__on_name_identity_change)
+	#----------------------------------------------
+	def __on_name_identity_change(self):
+		self.patient_selector.SetValue(self.curr_pat['description'])
+		self.txt_age.SetValue(self.curr_pat['medical_age'])
+	#----------------------------------------------
 	def _on_post_patient_selection(self, **kwargs):
 		# needed because GUI stuff can't be called from a thread (and that's
 		# where we are coming from via backend listener -> dispatcher)
 		wx.CallAfter(self.__on_post_patient_selection, **kwargs)
-		wx.CallAfter(self.__update_allergies, **kwargs)
 	#----------------------------------------------
 	def __on_post_patient_selection(self, **kwargs):
 		age = self.curr_pat['medical_age']
 		# FIXME: if the age is below, say, 2 hours we should fire
 		# a timer here that updates the age in increments of 1 minute ... :-)
-		self.txt_age.SetValue(age)
 		self.patient_selector.SetValue(self.curr_pat['description'])
+		self.txt_age.SetValue(age)
+		self.__update_allergies()
 	#-------------------------------------------------------
 	def __on_display_demographics(self, evt):
 		print "display patient demographic window now"
@@ -432,6 +442,21 @@ if __name__ == "__main__":
 	app.MainLoop()
 #===========================================================
 # $Log: gmTopPanel.py,v $
+# Revision 1.89  2007/12/02 11:00:58  ncq
+# - update age, too, on pat identity change
+#
+# Revision 1.88  2007/11/28 22:36:41  ncq
+# - listen on identity/name changes for current patient
+#
+# Revision 1.87  2007/10/25 12:27:29  ncq
+# - cleanup
+#
+# Revision 1.86  2007/10/25 12:21:39  ncq
+# - listen to the proper signals for allergy changes
+#
+# Revision 1.85  2007/08/12 00:12:41  ncq
+# - no more gmSignals.py
+#
 # Revision 1.84  2007/05/21 17:13:43  ncq
 # - translate "Allergies" in allergy field tooltip
 #
