@@ -42,8 +42,8 @@ care of all the pre- and post-GUI runtime environment setup.
 """
 #==========================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gnumed.py,v $
-# $Id: gnumed.py,v 1.123 2007/10/21 20:21:17 ncq Exp $
-__version__ = "$Revision: 1.123 $"
+# $Id: gnumed.py,v 1.123.2.1 2008/02/21 17:18:45 ncq Exp $
+__version__ = "$Revision: 1.123.2.1 $"
 __author__  = "H. Herb <hherb@gnumed.net>, K. Hilbert <Karsten.Hilbert@gmx.net>, I. Haywood <i.haywood@ugrad.unimelb.edu.au>"
 __license__ = "GPL (details at http://www.gnu.org)"
 
@@ -254,6 +254,9 @@ def check_help_request():
 #==========================================================
 # main - launch the GNUmed wxPython GUI client
 #----------------------------------------------------------
+import logging
+logging.raiseExceptions = False
+
 setup_console_exption_handler()
 setup_signal_handlers()
 setup_logging()
@@ -295,6 +298,9 @@ _log.Log(gmLog.lInfo, 'Normally shutting down as main module.')
 
 #==========================================================
 # $Log: gnumed.py,v $
+# Revision 1.123.2.1  2008/02/21 17:18:45  ncq
+# - silence exception generated by logging bug on windows
+#
 # Revision 1.123  2007/10/21 20:21:17  ncq
 # - no more mandatory global config file
 #
