@@ -6,7 +6,7 @@
 #
 # @copyright: author
 #======================================================================
-__version__ = "$Revision: 1.13 $"
+__version__ = "$Revision: 1.14 $"
 __author__ = "Carlos Moro"
 __license__ = 'GPL (details at http://www.gnu.org)'
 
@@ -48,11 +48,7 @@ if __name__ == "__main__":
 
     import sys
 
-    try:
-        import wxversion
-        import wx
-    except ImportError:
-        from wxPython import wx
+    import wx
 
     from Gnumed.pycommon import gmCfg
     from Gnumed.exporters import gmPatientExporter
@@ -97,6 +93,9 @@ if __name__ == "__main__":
 
 #======================================================================
 # $Log: gmEMRBrowserPlugin.py,v $
+# Revision 1.14  2007/10/12 07:28:24  ncq
+# - lots of import related cleanup
+#
 # Revision 1.13  2006/10/31 16:06:19  ncq
 # - no more gmPG
 #
