@@ -3,13 +3,11 @@
 # later to evolve into a more complete "provider-centric hub"
 #=====================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gui/gmProviderInboxPlugin.py,v $
-# $Id: gmProviderInboxPlugin.py,v 1.7 2006/12/17 22:21:05 ncq Exp $
-__version__ = "$Revision: 1.7 $"
+# $Id: gmProviderInboxPlugin.py,v 1.8 2007/10/12 07:28:25 ncq Exp $
+__version__ = "$Revision: 1.8 $"
 __author__ = "Karsten Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL"
 
-import wx
-
 from Gnumed.wxpython import gmPlugin, gmProviderInboxWidgets
 
 #======================================================================
@@ -35,6 +33,9 @@ class gmProviderInboxPlugin(gmPlugin.cNotebookPlugin):
 		return True
 #======================================================================
 # $Log: gmProviderInboxPlugin.py,v $
+# Revision 1.8  2007/10/12 07:28:25  ncq
+# - lots of import related cleanup
+#
 # Revision 1.7  2006/12/17 22:21:05  ncq
 # - cleanup
 #
