@@ -11,8 +11,8 @@ TODO:
 """
 #=============================================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gui/gmXdtViewer.py,v $
-# $Id: gmXdtViewer.py,v 1.27 2007/05/21 13:06:39 ncq Exp $
-__version__ = "$Revision: 1.27 $"
+# $Id: gmXdtViewer.py,v 1.29 2007/08/29 14:43:43 ncq Exp $
+__version__ = "$Revision: 1.29 $"
 __author__ = "S.Hilbert, K.Hilbert"
 
 import sys, os, os.path, codecs
@@ -37,7 +37,8 @@ class cXdtListPnl(wxgXdtListPnl.wxgXdtListPnl):
 
 		self.__cols = [
 			_('xDT field'),
-			_('field content')
+			_('field content'),
+			_('xDT field ID')
 		]
 		self.__init_ui()
 	#--------------------------------------------------------------
@@ -92,7 +93,7 @@ class cXdtListPnl(wxgXdtListPnl.wxgXdtListPnl):
 		encoding = gmXdtObjects.determine_xdt_encoding(filename = filename)
 		if encoding is None:
 			encoding = 'utf8'
-			gmDispatcher.send(signal = gmSignals.statustext(), msg = _('Encoding missing in xDT file. Assuming [%s].') % encoding)
+			gmDispatcher.send(signal = 'statustext', msg = _('Encoding missing in xDT file. Assuming [%s].') % encoding)
 			_log.Log(gmLog.lWarn, 'xDT file [%s] does not define an encoding, assuming [%s]' % (filename, encoding))
 
 		try:
@@ -130,6 +131,7 @@ class cXdtListPnl(wxgXdtListPnl.wxgXdtListPnl):
 
 			self._LCTRL_xdt.InsertStringItem(index=idx, label=left)
 			self._LCTRL_xdt.SetStringItem(index=idx, col=1, label=right)
+			self._LCTRL_xdt.SetStringItem(index=idx, col=2, label=field)
 			idx += 1
 
 		xdt_file.close()
@@ -418,6 +420,12 @@ if __name__ == '__main__':
 
 #=============================================================================
 # $Log: gmXdtViewer.py,v $
+# Revision 1.29  2007/08/29 14:43:43  ncq
+# - show xDT field ID in third column to enable more comfortable debugging
+#
+# Revision 1.28  2007/08/12 00:12:41  ncq
+# - no more gmSignals.py
+#
 # Revision 1.27  2007/05/21 13:06:39  ncq
 # - proper chatch-all wildcard * rather than *.*
 #
